package server

import (
	"net/http"
	"time"

	"github.com/NYTimes/gziphandler"
)

func setupFaviconHandlers() {
	http.Handle("/favicon.ico", gziphandler.GzipHandler(http.HandlerFunc(faviconIco)))
	http.Handle("/favicon-16x16.png", gziphandler.GzipHandler(http.HandlerFunc(favicon16x16Png)))
	http.Handle("/favicon-32x32.png", gziphandler.GzipHandler(http.HandlerFunc(favicon32x32Png)))
	http.Handle("/favicon-96x96.png", gziphandler.GzipHandler(http.HandlerFunc(favicon96x96Png)))
	http.Handle("/android-chrome-192x192.png", gziphandler.GzipHandler(http.HandlerFunc(androidChrome192x192Png)))
	http.Handle("/android-chrome-144x144.png", gziphandler.GzipHandler(http.HandlerFunc(androidChrome144x144Png)))
	http.Handle("/android-chrome-96x96.png", gziphandler.GzipHandler(http.HandlerFunc(androidChrome96x96Png)))
	http.Handle("/android-chrome-72x72.png", gziphandler.GzipHandler(http.HandlerFunc(androidChrome72x72Png)))
	http.Handle("/android-chrome-48x48.png", gziphandler.GzipHandler(http.HandlerFunc(androidChrome48x48Png)))
	http.Handle("/android-chrome-36x36.png", gziphandler.GzipHandler(http.HandlerFunc(androidChrome36x36Png)))
	http.Handle("/apple-touch-icon-180x180.png", gziphandler.GzipHandler(http.HandlerFunc(appleTouchIcon180x180Png)))
	http.Handle("/apple-touch-icon-152x152.png", gziphandler.GzipHandler(http.HandlerFunc(appleTouchIcon152x152Png)))
	http.Handle("/apple-touch-icon-144x144.png", gziphandler.GzipHandler(http.HandlerFunc(appleTouchIcon144x144Png)))
	http.Handle("/apple-touch-icon-120x120.png", gziphandler.GzipHandler(http.HandlerFunc(appleTouchIcon120x120Png)))
	http.Handle("/apple-touch-icon-114x114.png", gziphandler.GzipHandler(http.HandlerFunc(appleTouchIcon114x114Png)))
	http.Handle("/apple-touch-icon-76x76.png", gziphandler.GzipHandler(http.HandlerFunc(appleTouchIcon76x76Png)))
	http.Handle("/apple-touch-icon-72x72.png", gziphandler.GzipHandler(http.HandlerFunc(appleTouchIcon72x72Png)))
	http.Handle("/apple-touch-icon-60x60.png", gziphandler.GzipHandler(http.HandlerFunc(appleTouchIcon60x60Png)))
	http.Handle("/apple-touch-icon-57x57.png", gziphandler.GzipHandler(http.HandlerFunc(appleTouchIcon57x57Png)))
	http.Handle("/apple-touch-icon.png", gziphandler.GzipHandler(http.HandlerFunc(appleTouchIconPng)))
	http.Handle("/apple-touch-icon-precomposed.png", gziphandler.GzipHandler(http.HandlerFunc(appleTouchIconPrecomposedPng)))
	http.Handle("/mstile-144x144.png", gziphandler.GzipHandler(http.HandlerFunc(mstile144x144Png)))
	http.Handle("/mstile-150x150.png", gziphandler.GzipHandler(http.HandlerFunc(mstile150x150Png)))
	http.Handle("/mstile-310x150.png", gziphandler.GzipHandler(http.HandlerFunc(mstile310x150Png)))
	http.Handle("/mstile-310x310.png", gziphandler.GzipHandler(http.HandlerFunc(mstile310x310Png)))
	http.Handle("/mstile-70x70.png", gziphandler.GzipHandler(http.HandlerFunc(mstile70x70Png)))
	http.Handle("/browserconfig.xml", gziphandler.GzipHandler(http.HandlerFunc(browserconfigXML)))
	http.Handle("/manifest.json", gziphandler.GzipHandler(http.HandlerFunc(manifestJSON)))
	http.Handle("/safari-pinned-tab.svg", gziphandler.GzipHandler(http.HandlerFunc(safariPinnedTabSvg)))
}

func setExpiresHeader(w http.ResponseWriter) {
	t := time.Now().Add(time.Duration(365*24) * time.Hour)
	w.Header().Set("Expires", t.Format(time.RFC1123))
}

func faviconIco(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/x-icon")
	setExpiresHeader(w)

	w.Write([]byte{
		0x00, 0x00, 0x01, 0x00, 0x03, 0x00, 0x10, 0x10, 0x10, 0x00, 0x01, 0x00,
		0x04, 0x00, 0x28, 0x01, 0x00, 0x00, 0x36, 0x00, 0x00, 0x00, 0x20, 0x20,
		0x10, 0x00, 0x01, 0x00, 0x04, 0x00, 0xe8, 0x02, 0x00, 0x00, 0x5e, 0x01,
		0x00, 0x00, 0x30, 0x30, 0x10, 0x00, 0x01, 0x00, 0x04, 0x00, 0x68, 0x06,
		0x00, 0x00, 0x46, 0x04, 0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x10, 0x00,
		0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x01, 0x00, 0x04, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x66, 0x63,
		0x58, 0x00, 0x32, 0x2f, 0x27, 0x00, 0x89, 0x85, 0x7a, 0x00, 0x38, 0x35,
		0x2c, 0x00, 0x3f, 0x3c, 0x33, 0x00, 0x54, 0x51, 0x47, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11,
		0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11,
		0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x13,
		0x11, 0x11, 0x11, 0x11, 0x31, 0x11, 0x11, 0x32, 0x51, 0x14, 0x41, 0x15,
		0x23, 0x11, 0x11, 0x42, 0x41, 0x30, 0x20, 0x13, 0x24, 0x11, 0x11, 0x42,
		0x31, 0x10, 0x25, 0x13, 0x24, 0x11, 0x11, 0x42, 0x31, 0x42, 0x04, 0x13,
		0x24, 0x11, 0x11, 0x42, 0x41, 0x15, 0x04, 0x13, 0x24, 0x11, 0x11, 0x32,
		0x51, 0x11, 0x11, 0x15, 0x23, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11,
		0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11,
		0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11,
		0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x11, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x40, 0x00,
		0x00, 0x00, 0x01, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xb6, 0xb1, 0xa4, 0x00, 0xc5, 0xc0,
		0xb2, 0x00, 0x4b, 0x48, 0x3f, 0x00, 0x37, 0x34, 0x2c, 0x00, 0x30, 0x2d,
		0x25, 0x00, 0xa4, 0xa0, 0x93, 0x00, 0x97, 0x93, 0x87, 0x00, 0x32, 0x2f,
		0x27, 0x00, 0x5e, 0x5b, 0x51, 0x00, 0x82, 0x7e, 0x72, 0x00, 0x70, 0x6c,
		0x61, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x44, 0x47, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x74, 0x44, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x89, 0xa3, 0x77, 0x77, 0x74, 0x44, 0x77,
		0x77, 0x7a, 0x9a, 0x77, 0x77, 0x77, 0x77, 0x77, 0x74, 0x51, 0xa3, 0x77,
		0x77, 0x32, 0x23, 0x47, 0x77, 0x7a, 0x00, 0x37, 0x77, 0x77, 0x77, 0x77,
		0x74, 0x56, 0x47, 0x77, 0x43, 0x50, 0x00, 0x84, 0x77, 0x74, 0x90, 0x37,
		0x77, 0x77, 0x77, 0x77, 0x74, 0x56, 0x47, 0x77, 0x73, 0x82, 0x36, 0x03,
		0x77, 0x74, 0x90, 0x37, 0x77, 0x77, 0x77, 0x77, 0x74, 0x56, 0x47, 0x77,
		0x77, 0x43, 0x80, 0x03, 0x77, 0x74, 0x90, 0x37, 0x77, 0x77, 0x77, 0x77,
		0x74, 0x56, 0x47, 0x77, 0x74, 0xa0, 0x16, 0x24, 0x77, 0x74, 0x90, 0x37,
		0x77, 0x77, 0x77, 0x77, 0x74, 0x56, 0x47, 0x77, 0x73, 0x09, 0x34, 0x47,
		0x77, 0x74, 0x90, 0x37, 0x77, 0x77, 0x77, 0x77, 0x74, 0x56, 0x47, 0x77,
		0x73, 0x56, 0x8a, 0x84, 0x77, 0x74, 0x90, 0x37, 0x77, 0x77, 0x77, 0x77,
		0x74, 0x56, 0x47, 0x77, 0x74, 0x26, 0x05, 0x84, 0x77, 0x74, 0x90, 0x37,
		0x77, 0x77, 0x77, 0x77, 0x74, 0x56, 0x47, 0x77, 0x77, 0x47, 0x37, 0x47,
		0x77, 0x74, 0x90, 0x37, 0x77, 0x77, 0x77, 0x77, 0x74, 0x51, 0x93, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x79, 0x10, 0x37, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x8a, 0x83, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x78, 0xa8, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x44, 0x47, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x74, 0x44, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x77,
		0x77, 0x77, 0x77, 0x77, 0x77, 0x77, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x28, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00, 0x60, 0x00,
		0x00, 0x00, 0x01, 0x00, 0x04, 0x00, 0x00, 0x00, 0x00, 0x00, 0x80, 0x04,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x10, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xed, 0xe8, 0xd8, 0x00, 0x91, 0x8d,
		0x81, 0x00, 0xe2, 0xdd, 0xce, 0x00, 0x7f, 0x7b, 0x70, 0x00, 0xa3, 0x9e,
		0x91, 0x00, 0x53, 0x50, 0x46, 0x00, 0x30, 0x2d, 0x25, 0x00, 0xba, 0xb6,
		0xa8, 0x00, 0x32, 0x2f, 0x27, 0x00, 0x6b, 0x68, 0x5d, 0x00, 0x41, 0x3e,
		0x35, 0x00, 0xd2, 0xce, 0xbf, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x86, 0x66, 0x66, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x86, 0x66, 0x68, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x6a, 0x55, 0x5a, 0x68, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x85, 0x55, 0xa8, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x22, 0xb9, 0x68, 0x88, 0x88, 0x88, 0x66, 0x66, 0x88,
		0x88, 0x88, 0x86, 0x5b, 0x22, 0x16, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x01, 0x5a, 0x68, 0x88, 0x88, 0x88, 0xa5, 0x5a, 0x86,
		0x88, 0x88, 0x88, 0xa5, 0x32, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x09, 0x66, 0x88, 0x88, 0x88, 0x81, 0xbb, 0x2b, 0x45,
		0x68, 0x88, 0x88, 0x86, 0x52, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x09, 0x68, 0x88, 0x88, 0x86, 0xa7, 0x43, 0x91, 0x27,
		0xa6, 0x88, 0x88, 0x86, 0x52, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x09, 0x68, 0x88, 0x88, 0x88, 0x8a, 0x86, 0x66, 0x10,
		0x96, 0x88, 0x88, 0x86, 0x52, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x09, 0x68, 0x88, 0x88, 0x88, 0x86, 0x66, 0x8a, 0x72,
		0x56, 0x88, 0x88, 0x86, 0x52, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x09, 0x68, 0x88, 0x88, 0x88, 0x86, 0xa3, 0x4b, 0x04,
		0x88, 0x88, 0x88, 0x86, 0x52, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x09, 0x68, 0x88, 0x88, 0x88, 0x65, 0xb2, 0xb4, 0x9a,
		0x68, 0x88, 0x88, 0x86, 0x52, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x09, 0x68, 0x88, 0x88, 0x88, 0x84, 0x29, 0xa8, 0x66,
		0x88, 0x88, 0x88, 0x86, 0x52, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x09, 0x68, 0x88, 0x88, 0x88, 0x87, 0x78, 0x66, 0x68,
		0x88, 0x88, 0x88, 0x86, 0x52, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x09, 0x68, 0x88, 0x88, 0x88, 0x61, 0x21, 0x99, 0x11,
		0x88, 0x88, 0x88, 0x86, 0x52, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x09, 0x68, 0x88, 0x88, 0x88, 0x6a, 0x1b, 0x22, 0xb1,
		0x88, 0x88, 0x88, 0x86, 0x52, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x09, 0x68, 0x88, 0x88, 0x88, 0x86, 0x8a, 0x55, 0xa8,
		0x88, 0x88, 0x88, 0x86, 0x52, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x09, 0x66, 0x88, 0x88, 0x88, 0x88, 0x86, 0x66, 0x68,
		0x88, 0x88, 0x88, 0x66, 0x52, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x63, 0x04, 0x35, 0x68, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x86, 0xa3, 0x10, 0x46, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x69, 0xbb, 0xb9, 0x68, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x86, 0x5b, 0xbb, 0x16, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0xaa, 0xa8, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x8a, 0xaa, 0xa8, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x66, 0x68, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x86, 0x66, 0x68, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88,
		0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x88, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
	})
}

func favicon16x16Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x10, 0x00, 0x00, 0x00, 0x10,
		0x04, 0x03, 0x00, 0x00, 0x00, 0xed, 0xdd, 0xe2, 0x52, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x15, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0x2a, 0x33, 0x36, 0x7d, 0x89, 0x8d, 0x31, 0x3b, 0x3e, 0x45, 0x50,
		0x53, 0x58, 0x63, 0x66, 0x73, 0x7f, 0x83, 0xc7, 0x29, 0xdf, 0x4e, 0x00,
		0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00, 0x0b, 0x13, 0x00,
		0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00, 0x00, 0x00, 0x2e,
		0x49, 0x44, 0x41, 0x54, 0x08, 0xd7, 0x63, 0x60, 0x20, 0x09, 0x88, 0x39,
		0x30, 0x30, 0xb0, 0x24, 0x02, 0x19, 0x42, 0x06, 0x2c, 0xc1, 0x8c, 0xca,
		0x20, 0x86, 0x80, 0x11, 0x8c, 0xc1, 0xaa, 0x02, 0x65, 0x88, 0xaa, 0x82,
		0x19, 0x62, 0x0e, 0xcc, 0x06, 0x60, 0xc5, 0x24, 0x00, 0x00, 0x28, 0xb0,
		0x04, 0x21, 0x5d, 0x42, 0x2f, 0x5e, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54,
		0x58, 0x74, 0x52, 0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c,
		0x65, 0x20, 0x74, 0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00,
		0x00, 0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca,
		0x4f, 0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63,
		0x0b, 0x13, 0x23, 0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80,
		0x34, 0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8,
		0xc4, 0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e,
		0x00, 0xea, 0x17, 0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00,
		0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func favicon32x32Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x20, 0x00, 0x00, 0x00, 0x20,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x81, 0x54, 0x67, 0xc7, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x2a, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0x1f, 0x28, 0x2b, 0x21, 0x2a, 0x2d, 0x25, 0x2e, 0x32, 0xa5, 0xb2,
		0xb7, 0x73, 0x7f, 0x83, 0x94, 0xa1, 0xa5, 0x88, 0x94, 0x98, 0x4f, 0x59,
		0x5d, 0x2b, 0x34, 0x38, 0x5a, 0x65, 0x69, 0x65, 0x70, 0x74, 0xb3, 0xc1,
		0xc6, 0x3d, 0x47, 0x4a, 0x0c, 0xb6, 0xde, 0xb1, 0x00, 0x00, 0x00, 0x09,
		0x70, 0x48, 0x59, 0x73, 0x00, 0x00, 0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13,
		0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00, 0x00, 0x00, 0x72, 0x49, 0x44, 0x41,
		0x54, 0x28, 0xcf, 0x63, 0x60, 0x18, 0xc4, 0x40, 0x50, 0x00, 0x42, 0x33,
		0x0a, 0x42, 0x05, 0xba, 0x17, 0x43, 0x68, 0x8e, 0x1d, 0x10, 0x9a, 0x29,
		0x27, 0x12, 0xc2, 0x30, 0x3d, 0x62, 0x00, 0x11, 0x48, 0x07, 0x6a, 0x51,
		0x30, 0x50, 0x60, 0x60, 0x0c, 0x41, 0x08, 0x30, 0x5d, 0x77, 0x6b, 0x44,
		0x11, 0x60, 0x4e, 0xef, 0x6e, 0x42, 0x11, 0xe0, 0x74, 0x9d, 0x28, 0x80,
		0xaa, 0x65, 0xc9, 0xf1, 0x4b, 0x28, 0x02, 0x0c, 0x92, 0x2d, 0xce, 0xa8,
		0x5a, 0x7a, 0xa7, 0xa3, 0x0a, 0x68, 0xa6, 0xb8, 0x2c, 0x42, 0x08, 0xe4,
		0x6c, 0x66, 0x60, 0x98, 0x7b, 0x53, 0x81, 0xc1, 0xca, 0x05, 0x22, 0xc0,
		0xd0, 0x0a, 0x14, 0x60, 0x12, 0x62, 0x60, 0xb0, 0x8a, 0xc2, 0xe5, 0xb9,
		0x41, 0x09, 0x00, 0x14, 0x29, 0x1b, 0xf2, 0xaf, 0xc4, 0x10, 0x7e, 0x00,
		0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52, 0x61, 0x77, 0x20, 0x70,
		0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74, 0x79, 0x70, 0x65, 0x20,
		0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08,
		0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00,
		0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23, 0x13, 0x4b, 0x93, 0x14,
		0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54,
		0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb,
		0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17, 0x11, 0x74, 0xf2, 0x42,
		0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42,
		0x60, 0x82,
	})
}

func favicon96x96Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x60,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x10, 0xb6, 0x6a, 0x0b, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x1e, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0xdd, 0xed, 0xf1, 0x2b, 0x34, 0x38, 0x4a, 0x54, 0x58, 0xd3, 0xe2,
		0xe7, 0xad, 0xbb, 0xc0, 0x8c, 0x98, 0x9c, 0x5a, 0x65, 0x69, 0xc0, 0xcf,
		0xd3, 0x77, 0x83, 0x87, 0x7b, 0xa0, 0xa9, 0x43, 0x00, 0x00, 0x00, 0x09,
		0x70, 0x48, 0x59, 0x73, 0x00, 0x00, 0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13,
		0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00, 0x00, 0x01, 0x11, 0x49, 0x44, 0x41,
		0x54, 0x58, 0xc3, 0xed, 0x95, 0x3b, 0x0b, 0xc2, 0x30, 0x10, 0x80, 0x25,
		0x1d, 0x9c, 0x0f, 0xaa, 0xd4, 0x2d, 0xb4, 0x68, 0x75, 0x93, 0xba, 0xb8,
		0x16, 0x75, 0x70, 0x2c, 0xad, 0x5a, 0x37, 0x5f, 0x2d, 0xba, 0x89, 0x0a,
		0xc1, 0x5d, 0x21, 0xa3, 0x8f, 0xc1, 0xbf, 0x6b, 0x5d, 0xc4, 0x21, 0xc1,
		0xdc, 0x26, 0x78, 0xdf, 0xd8, 0xeb, 0x47, 0x7a, 0x8f, 0x5c, 0x4b, 0x25,
		0x82, 0x20, 0x08, 0xe2, 0xaf, 0x60, 0xae, 0xeb, 0x72, 0x65, 0x44, 0x13,
		0x68, 0x48, 0x29, 0x2f, 0xaa, 0xf7, 0xad, 0x54, 0xca, 0x58, 0xf1, 0xbc,
		0x0e, 0x00, 0x33, 0x95, 0x50, 0x2e, 0x02, 0x3d, 0xa5, 0x70, 0x1e, 0xa9,
		0x4f, 0x18, 0xa5, 0x1a, 0x61, 0xa1, 0xcb, 0xc1, 0x0f, 0xd5, 0xc2, 0x4c,
		0x57, 0x0f, 0xeb, 0x27, 0x04, 0x4f, 0xec, 0x03, 0x8c, 0xd0, 0x4a, 0xfa,
		0xfd, 0xf3, 0xd2, 0x5c, 0xb0, 0xa2, 0xa2, 0xf6, 0x50, 0x33, 0x17, 0xea,
		0x30, 0xd8, 0xe4, 0x09, 0x42, 0x38, 0x38, 0xbb, 0x22, 0x8d, 0x87, 0xb9,
		0x70, 0xad, 0x22, 0xab, 0x34, 0xaf, 0x21, 0x85, 0x6b, 0x85, 0xe3, 0x84,
		0x83, 0x1d, 0x73, 0x94, 0xd0, 0x00, 0x7b, 0x7c, 0xe7, 0x08, 0x81, 0xad,
		0x00, 0xec, 0x29, 0x47, 0x74, 0xda, 0x5f, 0x87, 0x00, 0x31, 0x66, 0x96,
		0xd8, 0x31, 0x81, 0x77, 0xe6, 0x66, 0xd3, 0xea, 0x45, 0xf6, 0x16, 0x37,
		0xde, 0x5d, 0xb8, 0xe0, 0x84, 0x26, 0x42, 0x08, 0x90, 0x27, 0xb0, 0xac,
		0x68, 0x82, 0x17, 0x39, 0x6d, 0x63, 0x21, 0x72, 0xc6, 0x79, 0x0a, 0x43,
		0xe3, 0xb2, 0xb2, 0xf9, 0xeb, 0xfe, 0x38, 0x37, 0xf3, 0x3e, 0xf8, 0xd9,
		0xe9, 0xe3, 0x86, 0x9a, 0x54, 0x89, 0x75, 0x3a, 0xc1, 0xf7, 0xe1, 0x9b,
		0x88, 0xb6, 0x72, 0xad, 0x8b, 0xa3, 0x46, 0xd0, 0x2d, 0xe3, 0x50, 0xb7,
		0x8c, 0x91, 0x82, 0x25, 0x84, 0xee, 0x93, 0x84, 0xd8, 0xd1, 0x0f, 0x97,
		0x20, 0x08, 0xe2, 0xbf, 0x78, 0x02, 0x67, 0xd4, 0x49, 0xc1, 0xee, 0xc2,
		0x8d, 0x6c, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52, 0x61,
		0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74, 0x79,
		0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c, 0xe3,
		0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc, 0x49,
		0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23, 0x13,
		0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64, 0x03,
		0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4, 0x1c,
		0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17, 0x11,
		0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e,
		0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func androidChrome192x192Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0xc0, 0x00, 0x00, 0x00, 0xc0,
		0x04, 0x03, 0x00, 0x00, 0x00, 0xa0, 0xf2, 0x71, 0x34, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00,
		0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00,
		0x00, 0x00, 0x21, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b, 0x2e, 0xdc, 0xec,
		0xf0, 0x1e, 0x26, 0x29, 0xcd, 0xdd, 0xe2, 0x94, 0xa1, 0xa6, 0x44, 0x4e,
		0x51, 0x67, 0x72, 0x76, 0x5e, 0x68, 0x6c, 0xae, 0xbc, 0xc1, 0x2e, 0x38,
		0x3b, 0x7d, 0x89, 0x8d, 0x1f, 0x1e, 0x21, 0x11, 0x00, 0x00, 0x02, 0x17,
		0x49, 0x44, 0x41, 0x54, 0x78, 0xda, 0xed, 0x98, 0xbd, 0x4b, 0xc3, 0x40,
		0x1c, 0x86, 0x43, 0xa0, 0x4a, 0xdc, 0x42, 0x14, 0x3a, 0x86, 0x2c, 0xa2,
		0x9b, 0x14, 0x6d, 0x75, 0x52, 0xac, 0x52, 0x3b, 0x15, 0xa5, 0xf5, 0x63,
		0x2a, 0x5a, 0x3f, 0x27, 0xf1, 0xab, 0xe8, 0x26, 0xad, 0xda, 0x3a, 0x05,
		0xb5, 0x6a, 0x9d, 0x14, 0x3f, 0xa8, 0xfd, 0x2b, 0xbd, 0x4b, 0x1a, 0xab,
		0x20, 0x9a, 0x68, 0x5e, 0x54, 0x78, 0x9f, 0xa9, 0xc3, 0xdd, 0x3d, 0xf4,
		0xee, 0x72, 0xef, 0xef, 0x4e, 0x51, 0x08, 0x21, 0x84, 0x10, 0x42, 0x08,
		0x21, 0x84, 0x10, 0x42, 0x08, 0x21, 0x84, 0x10, 0x42, 0xbe, 0x44, 0x6d,
		0x54, 0x1c, 0x8e, 0xfc, 0x77, 0xe9, 0x75, 0x7b, 0x54, 0xb6, 0xfc, 0x09,
		0xc6, 0x74, 0x87, 0x1e, 0xd3, 0xb7, 0xa0, 0xdf, 0xed, 0xa1, 0x2f, 0x52,
		0x10, 0x9e, 0x20, 0x9a, 0x4c, 0x26, 0x27, 0x02, 0x2c, 0xb2, 0x68, 0x9e,
		0x0a, 0x24, 0x18, 0xac, 0xd7, 0xeb, 0x76, 0x80, 0x9d, 0x27, 0x9a, 0x5f,
		0x06, 0x13, 0x04, 0xdf, 0xdd, 0xbd, 0x14, 0x50, 0xf0, 0x57, 0x04, 0x96,
		0x6c, 0x60, 0xe2, 0x04, 0xda, 0xec, 0x46, 0xf3, 0xa9, 0x98, 0x3d, 0x33,
		0x41, 0x82, 0x48, 0x63, 0x40, 0x0c, 0x63, 0x24, 0xd2, 0xfb, 0x18, 0x41,
		0x64, 0xbc, 0x75, 0xa8, 0xe9, 0x89, 0x5b, 0x88, 0x60, 0x4d, 0x7f, 0xa5,
		0x8a, 0x10, 0x74, 0x0c, 0x80, 0x05, 0xdb, 0x72, 0xfe, 0x63, 0x02, 0x90,
		0x40, 0x3b, 0x14, 0xe3, 0x4f, 0xce, 0xd7, 0x6b, 0x7b, 0x0f, 0x25, 0x88,
		0xa0, 0x53, 0xcc, 0x90, 0x1b, 0x42, 0x5a, 0x6e, 0x1c, 0x20, 0x50, 0x2f,
		0x44, 0xd0, 0x4d, 0xb7, 0x7e, 0xd7, 0xd6, 0x01, 0xff, 0xe0, 0x5a, 0xd7,
		0x87, 0x4c, 0xe4, 0x51, 0x71, 0xfe, 0xf9, 0x11, 0xf5, 0x73, 0xc1, 0xcc,
		0x47, 0x7b, 0x27, 0xcc, 0x35, 0x40, 0x0b, 0xe4, 0x14, 0xc5, 0xa1, 0x82,
		0xeb, 0xf6, 0x2e, 0xc2, 0x08, 0xba, 0xc4, 0x08, 0x27, 0x48, 0x81, 0xfc,
		0xd0, 0x8c, 0x47, 0xdb, 0x82, 0x09, 0x34, 0x59, 0xb3, 0x1a, 0xa7, 0xbb,
		0xb6, 0x89, 0x8a, 0xcc, 0x39, 0xe7, 0x1c, 0x35, 0xca, 0xcb, 0x36, 0x48,
		0x10, 0x39, 0x74, 0x8f, 0xea, 0xd8, 0x69, 0x06, 0x94, 0xc9, 0x37, 0x5e,
		0x20, 0x8c, 0x64, 0x40, 0x99, 0xbc, 0xe3, 0x19, 0x4e, 0x40, 0x82, 0xbe,
		0x85, 0x92, 0xab, 0x30, 0xf2, 0xa8, 0xba, 0xa8, 0x76, 0x50, 0x71, 0x14,
		0x71, 0x5c, 0x65, 0x57, 0x2b, 0x48, 0x43, 0xb7, 0x0d, 0x13, 0xa8, 0x7d,
		0x0b, 0x32, 0x3b, 0x37, 0x91, 0xb5, 0xa9, 0xfc, 0x20, 0x46, 0x91, 0x02,
		0x59, 0xbf, 0x54, 0x91, 0x02, 0xf9, 0xc5, 0x0d, 0x23, 0x05, 0xda, 0x3f,
		0x15, 0xa8, 0xef, 0xa6, 0x08, 0xb0, 0x06, 0x45, 0xfb, 0xed, 0x22, 0x4f,
		0x85, 0x2f, 0xb8, 0x3f, 0xf6, 0x92, 0x40, 0x6e, 0xd3, 0x7c, 0xf8, 0x82,
		0x3b, 0x11, 0x36, 0xe2, 0xf6, 0xa4, 0x9a, 0x39, 0x31, 0x43, 0xd1, 0x0c,
		0x40, 0x20, 0xee, 0x1d, 0xe9, 0xd5, 0x6c, 0xb1, 0x50, 0x12, 0x43, 0x0d,
		0x29, 0x10, 0x81, 0x08, 0x1b, 0xa7, 0x78, 0xff, 0x60, 0x09, 0xc2, 0x12,
		0x78, 0x89, 0x63, 0x03, 0x04, 0x4b, 0xed, 0xf1, 0xa3, 0xeb, 0x88, 0xc0,
		0xb9, 0x6a, 0xc4, 0xbc, 0x2b, 0xe0, 0x23, 0x26, 0x93, 0xb5, 0x5c, 0x4a,
		0x04, 0x9a, 0x91, 0x28, 0xef, 0xc3, 0x2e, 0xe2, 0x5a, 0x76, 0x6f, 0x65,
		0x75, 0xd7, 0x06, 0x3e, 0x25, 0xa8, 0x96, 0x65, 0x99, 0xa1, 0x54, 0x76,
		0xfe, 0x5f, 0x1c, 0xbf, 0x27, 0x08, 0xfa, 0xea, 0x58, 0x0e, 0xfa, 0xea,
		0xc8, 0x97, 0xdf, 0xdf, 0x15, 0x28, 0x07, 0x4d, 0x87, 0x67, 0xff, 0x8b,
		0x1c, 0x71, 0x7b, 0x34, 0x33, 0xfe, 0x9a, 0x5b, 0x2e, 0x41, 0x76, 0x6a,
		0xab, 0x8b, 0x42, 0x08, 0x21, 0x84, 0x10, 0x42, 0x08, 0x21, 0x84, 0x10,
		0x42, 0x08, 0x21, 0x84, 0x10, 0x3c, 0x2f, 0xdf, 0x01, 0xc5, 0xd4, 0xf0,
		0x44, 0x12, 0xf8, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52,
		0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74,
		0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c,
		0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc,
		0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23,
		0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64,
		0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4,
		0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17,
		0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
		0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func androidChrome144x144Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00, 0x90,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x15, 0x68, 0xff, 0x8b, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x1b, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0xdc, 0xec, 0xf0, 0x50, 0x5b, 0x5e, 0xb6, 0xc4, 0xc8, 0xd4, 0xe4,
		0xe9, 0x2e, 0x38, 0x3b, 0xa8, 0xb6, 0xba, 0x67, 0x72, 0x76, 0x86, 0x92,
		0x96, 0xd3, 0x99, 0xc6, 0x9f, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59,
		0x73, 0x00, 0x00, 0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a,
		0x9c, 0x18, 0x00, 0x00, 0x01, 0x6e, 0x49, 0x44, 0x41, 0x54, 0x68, 0xde,
		0xed, 0x97, 0x4d, 0x6b, 0xc2, 0x40, 0x10, 0x86, 0x25, 0x60, 0x93, 0xeb,
		0x90, 0xc5, 0xb3, 0x1f, 0xfd, 0xf0, 0x9a, 0x2a, 0xe2, 0x75, 0xeb, 0xd2,
		0x5e, 0x17, 0x4b, 0xf0, 0x5a, 0x51, 0x42, 0x8f, 0x6d, 0xd4, 0xa6, 0xc7,
		0x2a, 0x14, 0xf3, 0xb3, 0xbb, 0x49, 0x73, 0x69, 0x0f, 0x6e, 0xc8, 0x2c,
		0xc5, 0xc2, 0xfb, 0x9c, 0x87, 0x07, 0xb2, 0x3b, 0xf3, 0x6e, 0xa6, 0xd5,
		0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x0f, 0x18, 0x8c,
		0x0c, 0x13, 0x5d, 0xa7, 0x6a, 0x7a, 0xb2, 0xa4, 0x47, 0x86, 0xd0, 0x26,
		0x7a, 0x2d, 0xaa, 0x3a, 0x27, 0x4b, 0x2e, 0x1d, 0x8a, 0x94, 0x9a, 0xd9,
		0x44, 0x5b, 0xa5, 0xa4, 0x55, 0x14, 0x66, 0x59, 0x6a, 0x3b, 0xc9, 0x45,
		0x96, 0xed, 0xed, 0x22, 0x5d, 0xeb, 0x56, 0x7a, 0x10, 0x9d, 0xb9, 0x68,
		0x6e, 0x3a, 0xe2, 0x8a, 0x2f, 0x6a, 0x0f, 0xc7, 0x44, 0x62, 0x76, 0xec,
		0x72, 0x45, 0xd7, 0x92, 0x4a, 0x6e, 0x99, 0x22, 0x2f, 0xfa, 0xf6, 0xd0,
		0x1d, 0x53, 0xf4, 0x68, 0x86, 0x38, 0x49, 0x46, 0x92, 0x2d, 0xda, 0x53,
		0x98, 0xea, 0x56, 0x7c, 0xb3, 0x66, 0x8a, 0xda, 0x51, 0x75, 0x38, 0xde,
		0x8e, 0x27, 0xf2, 0x24, 0xbd, 0x38, 0xe9, 0x23, 0x9f, 0x44, 0xf7, 0xbc,
		0x44, 0xe6, 0xd3, 0x3e, 0xdc, 0x88, 0x22, 0x7a, 0x70, 0x33, 0x6b, 0x4b,
		0x12, 0x07, 0xed, 0x42, 0x64, 0x9e, 0x03, 0xf1, 0x9c, 0x6a, 0xbe, 0xc8,
		0x2f, 0x46, 0x4d, 0x4d, 0x77, 0xfc, 0xe9, 0xdf, 0x94, 0x93, 0x36, 0xfb,
		0xe4, 0xc7, 0xc8, 0xa6, 0x1c, 0xff, 0x90, 0x1d, 0x23, 0x26, 0x90, 0x56,
		0xd2, 0x41, 0x8c, 0x14, 0xc4, 0x45, 0xb6, 0x75, 0xb4, 0x8b, 0xcc, 0x5e,
		0x44, 0xbf, 0x3a, 0xbc, 0x71, 0xf8, 0x0f, 0xe8, 0x67, 0x87, 0x37, 0x16,
		0x05, 0x44, 0x4f, 0x4e, 0x44, 0xfe, 0xd9, 0x88, 0xbc, 0xea, 0x88, 0x2f,
		0xb8, 0x67, 0x14, 0x4c, 0xcb, 0xa7, 0xb1, 0xbd, 0xe5, 0xde, 0x5a, 0x40,
		0xf7, 0x87, 0x38, 0x9e, 0xbf, 0x49, 0x6e, 0x1f, 0x99, 0xdb, 0x12, 0xa3,
		0x64, 0x2c, 0xd9, 0x9d, 0x1d, 0x54, 0xcf, 0x23, 0x7b, 0xd6, 0xfc, 0x75,
		0xe5, 0x61, 0x4f, 0xff, 0xfc, 0x7d, 0xa5, 0x84, 0x9a, 0xa4, 0x0e, 0x7e,
		0x6b, 0xe2, 0x7e, 0xbf, 0xdf, 0x24, 0x21, 0xeb, 0xed, 0x1a, 0x76, 0x91,
		0xc8, 0xf3, 0xa3, 0xcd, 0x32, 0xcc, 0xf3, 0xe5, 0x1f, 0xae, 0x10, 0x6e,
		0x44, 0xce, 0xb6, 0x23, 0xb3, 0x65, 0x18, 0x6a, 0xec, 0x22, 0x35, 0x36,
		0x16, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0xbe, 0x00,
		0xcc, 0x88, 0x62, 0x15, 0xd0, 0x67, 0xc8, 0x90, 0x00, 0x00, 0x00, 0x57,
		0x7a, 0x54, 0x58, 0x74, 0x52, 0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66,
		0x69, 0x6c, 0x65, 0x20, 0x74, 0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74,
		0x63, 0x00, 0x00, 0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28,
		0x28, 0xca, 0x4f, 0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b,
		0x2e, 0x63, 0x0b, 0x13, 0x23, 0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20,
		0x44, 0x80, 0x34, 0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8,
		0xd4, 0xc8, 0xc4, 0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0,
		0x4a, 0x2e, 0x00, 0xea, 0x17, 0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00,
		0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func androidChrome96x96Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x60, 0x00, 0x00, 0x00, 0x60,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x10, 0xb6, 0x6a, 0x0b, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x1e, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0xdd, 0xed, 0xf1, 0x2b, 0x34, 0x38, 0x4a, 0x54, 0x58, 0xd3, 0xe2,
		0xe7, 0xad, 0xbb, 0xc0, 0x8c, 0x98, 0x9c, 0x5a, 0x65, 0x69, 0xc0, 0xcf,
		0xd3, 0x77, 0x83, 0x87, 0x7b, 0xa0, 0xa9, 0x43, 0x00, 0x00, 0x00, 0x09,
		0x70, 0x48, 0x59, 0x73, 0x00, 0x00, 0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13,
		0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00, 0x00, 0x01, 0x11, 0x49, 0x44, 0x41,
		0x54, 0x58, 0xc3, 0xed, 0x95, 0x3b, 0x0b, 0xc2, 0x30, 0x10, 0x80, 0x25,
		0x1d, 0x9c, 0x0f, 0xaa, 0xd4, 0x2d, 0xb4, 0x68, 0x75, 0x93, 0xba, 0xb8,
		0x16, 0x75, 0x70, 0x2c, 0xad, 0x5a, 0x37, 0x5f, 0x2d, 0xba, 0x89, 0x0a,
		0xc1, 0x5d, 0x21, 0xa3, 0x8f, 0xc1, 0xbf, 0x6b, 0x5d, 0xc4, 0x21, 0xc1,
		0xdc, 0x26, 0x78, 0xdf, 0xd8, 0xeb, 0x47, 0x7a, 0x8f, 0x5c, 0x4b, 0x25,
		0x82, 0x20, 0x08, 0xe2, 0xaf, 0x60, 0xae, 0xeb, 0x72, 0x65, 0x44, 0x13,
		0x68, 0x48, 0x29, 0x2f, 0xaa, 0xf7, 0xad, 0x54, 0xca, 0x58, 0xf1, 0xbc,
		0x0e, 0x00, 0x33, 0x95, 0x50, 0x2e, 0x02, 0x3d, 0xa5, 0x70, 0x1e, 0xa9,
		0x4f, 0x18, 0xa5, 0x1a, 0x61, 0xa1, 0xcb, 0xc1, 0x0f, 0xd5, 0xc2, 0x4c,
		0x57, 0x0f, 0xeb, 0x27, 0x04, 0x4f, 0xec, 0x03, 0x8c, 0xd0, 0x4a, 0xfa,
		0xfd, 0xf3, 0xd2, 0x5c, 0xb0, 0xa2, 0xa2, 0xf6, 0x50, 0x33, 0x17, 0xea,
		0x30, 0xd8, 0xe4, 0x09, 0x42, 0x38, 0x38, 0xbb, 0x22, 0x8d, 0x87, 0xb9,
		0x70, 0xad, 0x22, 0xab, 0x34, 0xaf, 0x21, 0x85, 0x6b, 0x85, 0xe3, 0x84,
		0x83, 0x1d, 0x73, 0x94, 0xd0, 0x00, 0x7b, 0x7c, 0xe7, 0x08, 0x81, 0xad,
		0x00, 0xec, 0x29, 0x47, 0x74, 0xda, 0x5f, 0x87, 0x00, 0x31, 0x66, 0x96,
		0xd8, 0x31, 0x81, 0x77, 0xe6, 0x66, 0xd3, 0xea, 0x45, 0xf6, 0x16, 0x37,
		0xde, 0x5d, 0xb8, 0xe0, 0x84, 0x26, 0x42, 0x08, 0x90, 0x27, 0xb0, 0xac,
		0x68, 0x82, 0x17, 0x39, 0x6d, 0x63, 0x21, 0x72, 0xc6, 0x79, 0x0a, 0x43,
		0xe3, 0xb2, 0xb2, 0xf9, 0xeb, 0xfe, 0x38, 0x37, 0xf3, 0x3e, 0xf8, 0xd9,
		0xe9, 0xe3, 0x86, 0x9a, 0x54, 0x89, 0x75, 0x3a, 0xc1, 0xf7, 0xe1, 0x9b,
		0x88, 0xb6, 0x72, 0xad, 0x8b, 0xa3, 0x46, 0xd0, 0x2d, 0xe3, 0x50, 0xb7,
		0x8c, 0x91, 0x82, 0x25, 0x84, 0xee, 0x93, 0x84, 0xd8, 0xd1, 0x0f, 0x97,
		0x20, 0x08, 0xe2, 0xbf, 0x78, 0x02, 0x67, 0xd4, 0x49, 0xc1, 0xee, 0xc2,
		0x8d, 0x6c, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52, 0x61,
		0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74, 0x79,
		0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c, 0xe3,
		0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc, 0x49,
		0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23, 0x13,
		0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64, 0x03,
		0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4, 0x1c,
		0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17, 0x11,
		0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e,
		0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func androidChrome72x72Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x48, 0x00, 0x00, 0x00, 0x48,
		0x04, 0x03, 0x00, 0x00, 0x00, 0xa7, 0xc3, 0xae, 0x74, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x21, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0x20, 0x29, 0x2c, 0x31, 0x3a, 0x3e, 0xbc, 0xca, 0xcf, 0xe0, 0xf0,
		0xf4, 0x92, 0x9f, 0xa3, 0xd2, 0xe1, 0xe6, 0x4c, 0x56, 0x5a, 0xa6, 0xb4,
		0xb8, 0x62, 0x6d, 0x71, 0x79, 0x85, 0x89, 0x47, 0x85, 0x87, 0xbd, 0x00,
		0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00, 0x0b, 0x13, 0x00,
		0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00, 0x00, 0x00, 0xf7,
		0x49, 0x44, 0x41, 0x54, 0x48, 0xc7, 0xed, 0x93, 0xb1, 0x6a, 0xc3, 0x30,
		0x10, 0x86, 0x75, 0x81, 0x52, 0xb2, 0xe9, 0x02, 0xc1, 0x78, 0x8b, 0xb5,
		0x68, 0xaf, 0x9d, 0xb4, 0x64, 0x75, 0xa2, 0x07, 0x48, 0x42, 0x5f, 0xc0,
		0x46, 0xb4, 0x5b, 0x9c, 0x45, 0x79, 0x81, 0x3a, 0x74, 0x2c, 0x85, 0xf4,
		0x01, 0x0a, 0xc5, 0x7d, 0xcb, 0x64, 0x70, 0x96, 0x3b, 0x92, 0x23, 0xbb,
		0xfe, 0x45, 0xe2, 0xe7, 0x03, 0xdd, 0xfd, 0xe2, 0x57, 0x2a, 0x2a, 0x2a,
		0xea, 0x3e, 0x01, 0x22, 0xb5, 0x90, 0x5a, 0x60, 0x8c, 0x51, 0x92, 0x05,
		0xbf, 0xf9, 0x4b, 0x46, 0xa8, 0x35, 0xb5, 0x60, 0xe3, 0x2a, 0x0a, 0xbd,
		0xfa, 0x92, 0x42, 0xcf, 0x81, 0xce, 0x64, 0xf7, 0x0c, 0x7a, 0x62, 0x83,
		0xc3, 0x98, 0x43, 0x9a, 0xed, 0x79, 0x1d, 0x82, 0x41, 0xd8, 0x81, 0x04,
		0x3d, 0xb6, 0xbe, 0xfa, 0xd4, 0xb7, 0x21, 0x38, 0xba, 0x7c, 0xb6, 0x14,
		0xa0, 0x51, 0x71, 0x30, 0xf6, 0x5f, 0x80, 0x12, 0xdf, 0x20, 0x6a, 0x25,
		0x42, 0x97, 0x35, 0x6f, 0x3e, 0x37, 0x91, 0x23, 0xf8, 0x73, 0xd3, 0x1f,
		0x31, 0x82, 0x61, 0xbb, 0x70, 0x2b, 0x2d, 0x85, 0x69, 0xbb, 0x62, 0x99,
		0x09, 0x90, 0x42, 0xbd, 0x77, 0x8d, 0x10, 0xe6, 0xf9, 0x48, 0xea, 0x2f,
		0x61, 0xbb, 0x0c, 0x31, 0xf5, 0x02, 0x94, 0xce, 0x77, 0xe6, 0xbb, 0x14,
		0x66, 0x4a, 0x17, 0x55, 0x5e, 0xbf, 0x4b, 0x7f, 0xd7, 0xcd, 0xfc, 0x74,
		0x7b, 0x35, 0xa7, 0xfe, 0xa2, 0x6d, 0x98, 0xf4, 0x8b, 0x3e, 0x30, 0xe8,
		0xed, 0x23, 0xbb, 0xd4, 0xad, 0x67, 0xba, 0x96, 0x42, 0xac, 0x1a, 0x4a,
		0x6d, 0x3c, 0x2d, 0x90, 0x0d, 0xac, 0x2d, 0x81, 0x59, 0xbc, 0xe6, 0x80,
		0xbc, 0xf9, 0x51, 0x51, 0x51, 0x82, 0x4e, 0x2a, 0x9b, 0x3c, 0x5f, 0x25,
		0x4c, 0xe1, 0xec, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52,
		0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74,
		0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c,
		0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc,
		0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23,
		0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64,
		0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4,
		0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17,
		0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
		0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func androidChrome48x48Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x30, 0x00, 0x00, 0x00, 0x30,
		0x04, 0x03, 0x00, 0x00, 0x00, 0xa5, 0x2c, 0xe4, 0xb4, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x24, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0x1f, 0x28, 0x2b, 0x44, 0x4f, 0x52, 0xcf, 0xde, 0xe3, 0x32, 0x3c,
		0x3f, 0x92, 0x9f, 0xa4, 0x5d, 0x68, 0x6b, 0x71, 0x7c, 0x80, 0xd9, 0xe9,
		0xee, 0xc0, 0xcf, 0xd3, 0x82, 0x8e, 0x92, 0xa9, 0xb7, 0xbb, 0xa6, 0x03,
		0x4f, 0x47, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00,
		0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00,
		0x00, 0x00, 0xa0, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb, 0x63, 0x60, 0x18,
		0x05, 0x03, 0x06, 0x5c, 0x1c, 0x10, 0x6c, 0x16, 0x24, 0x8e, 0xd8, 0xcc,
		0x69, 0x02, 0x30, 0x36, 0xa3, 0xe6, 0xcc, 0x05, 0x70, 0x09, 0xf1, 0xd6,
		0x22, 0x84, 0x0e, 0xf7, 0x15, 0x81, 0x08, 0x89, 0x36, 0x88, 0x06, 0x41,
		0xb0, 0x16, 0x65, 0x0c, 0x09, 0x16, 0x25, 0x07, 0xac, 0x12, 0x2c, 0x2b,
		0x8d, 0x67, 0x61, 0x95, 0xe0, 0xb2, 0x4a, 0x5b, 0x85, 0x55, 0x82, 0x7b,
		0x83, 0xa0, 0x00, 0x56, 0x09, 0x56, 0x33, 0x07, 0xec, 0x12, 0x42, 0x93,
		0xa7, 0xa6, 0x60, 0x77, 0x95, 0x7b, 0x64, 0x2b, 0x76, 0x09, 0x41, 0x96,
		0xcd, 0x8a, 0x58, 0x9d, 0xcb, 0x28, 0xb8, 0x22, 0x11, 0x9b, 0x84, 0x77,
		0x78, 0x96, 0xb5, 0x03, 0x56, 0x7f, 0xcc, 0xb4, 0x0c, 0x42, 0xb7, 0xa3,
		0x4b, 0x05, 0x44, 0x39, 0xa9, 0x30, 0x82, 0xc8, 0x62, 0x24, 0x09, 0x63,
		0x70, 0xb0, 0x33, 0x82, 0x09, 0x4d, 0x63, 0x44, 0xb0, 0xb3, 0x28, 0xa9,
		0x20, 0x82, 0x9d, 0x49, 0x09, 0x29, 0xd6, 0x04, 0x05, 0x90, 0xa2, 0x53,
		0x70, 0x34, 0x45, 0xd3, 0x1c, 0x00, 0x00, 0x46, 0x42, 0x24, 0xe7, 0x5b,
		0x76, 0xea, 0xdb, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52,
		0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74,
		0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c,
		0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc,
		0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23,
		0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64,
		0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4,
		0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17,
		0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
		0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func androidChrome36x36Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x24, 0x00, 0x00, 0x00, 0x24,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x13, 0x2e, 0x85, 0xab, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x24, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0x20, 0x29, 0x2c, 0x33, 0x3d, 0x40, 0x29, 0x33, 0x36, 0xbe, 0xcc,
		0xd1, 0xb2, 0xc0, 0xc4, 0x66, 0x71, 0x76, 0x7e, 0x8a, 0x8e, 0x3d, 0x46,
		0x4a, 0x8f, 0x9c, 0xa0, 0x49, 0x53, 0x57, 0xa3, 0xb0, 0xb5, 0x6b, 0x6e,
		0xe2, 0x46, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00,
		0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00,
		0x00, 0x00, 0x81, 0x49, 0x44, 0x41, 0x54, 0x28, 0xcf, 0x63, 0x60, 0x18,
		0xea, 0x80, 0x51, 0x10, 0xc6, 0x12, 0x14, 0x80, 0x32, 0x98, 0x94, 0x60,
		0x42, 0x4a, 0x0a, 0x50, 0x86, 0xb5, 0xb7, 0x22, 0x84, 0xc1, 0x3c, 0x65,
		0x13, 0x54, 0x99, 0xe9, 0x0c, 0x98, 0xee, 0x76, 0x27, 0x98, 0x50, 0x21,
		0x48, 0xf7, 0x0a, 0x03, 0x06, 0x06, 0x31, 0x14, 0xa1, 0xd4, 0xd0, 0xc9,
		0x68, 0x42, 0x12, 0x6e, 0x1a, 0x0b, 0x30, 0x84, 0x0c, 0x05, 0xd0, 0x35,
		0x96, 0x44, 0xa2, 0xab, 0x62, 0xe4, 0xc8, 0xf6, 0x10, 0x40, 0x15, 0x62,
		0x36, 0x94, 0xf2, 0x42, 0x13, 0x92, 0xda, 0x59, 0xba, 0x09, 0x59, 0xa8,
		0x98, 0x81, 0x41, 0x38, 0x7d, 0x1a, 0xd0, 0x0b, 0x66, 0x30, 0x21, 0x6b,
		0x4f, 0x45, 0xa0, 0xe3, 0x81, 0x5e, 0x66, 0x9e, 0x12, 0x04, 0x15, 0xe2,
		0x00, 0x39, 0x1c, 0x0c, 0xba, 0x1a, 0x70, 0x07, 0xce, 0xd0, 0x05, 0x00,
		0x36, 0x7b, 0x1b, 0xe8, 0x0f, 0x11, 0xdf, 0x6e, 0x00, 0x00, 0x00, 0x57,
		0x7a, 0x54, 0x58, 0x74, 0x52, 0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66,
		0x69, 0x6c, 0x65, 0x20, 0x74, 0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74,
		0x63, 0x00, 0x00, 0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28,
		0x28, 0xca, 0x4f, 0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b,
		0x2e, 0x63, 0x0b, 0x13, 0x23, 0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20,
		0x44, 0x80, 0x34, 0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8,
		0xd4, 0xc8, 0xc4, 0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0,
		0x4a, 0x2e, 0x00, 0xea, 0x17, 0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00,
		0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func appleTouchIcon180x180Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0xb4, 0x00, 0x00, 0x00, 0xb4,
		0x04, 0x03, 0x00, 0x00, 0x00, 0xcf, 0xe3, 0x1b, 0x01, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00,
		0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00,
		0x00, 0x00, 0x1e, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b, 0x2e, 0xdc, 0xec,
		0xf0, 0x1e, 0x27, 0x2a, 0x35, 0x3e, 0x42, 0x5a, 0x64, 0x67, 0xa1, 0xae,
		0xb3, 0xcb, 0xda, 0xdf, 0x72, 0x7e, 0x82, 0x8a, 0x96, 0x9a, 0xb3, 0xc1,
		0xc6, 0x85, 0x9e, 0x8f, 0xb6, 0x00, 0x00, 0x01, 0xec, 0x49, 0x44, 0x41,
		0x54, 0x68, 0xde, 0xed, 0x98, 0x4d, 0x4b, 0x03, 0x31, 0x10, 0x86, 0x43,
		0xb6, 0x52, 0xaf, 0x81, 0x36, 0xda, 0xdb, 0x92, 0x15, 0xbc, 0x2e, 0xba,
		0x55, 0xbc, 0x55, 0x5b, 0xc5, 0xa3, 0x82, 0xf5, 0xe3, 0x28, 0xe2, 0xc7,
		0x51, 0x51, 0x49, 0xbd, 0x29, 0x55, 0x8b, 0x47, 0xd1, 0xd6, 0xf6, 0xdf,
		0x9a, 0xec, 0x6e, 0x8b, 0xd0, 0x4b, 0x56, 0x27, 0x50, 0xe1, 0x7d, 0xa0,
		0x7b, 0xd9, 0xf4, 0x61, 0x09, 0x93, 0x99, 0xc9, 0x30, 0x06, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0xf7,
		0x04, 0x27, 0x23, 0xcb, 0xd0, 0x71, 0x39, 0xaf, 0xa7, 0xcb, 0x47, 0x8f,
		0x2e, 0xea, 0x53, 0x61, 0xa9, 0xb9, 0xaa, 0x37, 0xd3, 0xe5, 0x62, 0x0f,
		0xea, 0x5c, 0xbd, 0x56, 0x4c, 0xdd, 0xd3, 0xfa, 0xce, 0x55, 0xbd, 0x6e,
		0xd6, 0xee, 0xbb, 0xab, 0xb7, 0xb8, 0x0a, 0x9d, 0x43, 0x4a, 0x29, 0xf5,
		0x54, 0x40, 0x5d, 0x2c, 0x5e, 0x39, 0xd4, 0x50, 0x67, 0x61, 0x66, 0x7f,
		0xa1, 0x0f, 0x75, 0x94, 0x68, 0xad, 0x5b, 0xab, 0x9c, 0x5e, 0x1d, 0xdc,
		0xdb, 0x14, 0x20, 0xfb, 0xbd, 0x98, 0x5a, 0x1d, 0x3d, 0x64, 0xc9, 0x42,
		0xc8, 0x2b, 0x62, 0x35, 0xdf, 0x16, 0x63, 0x6a, 0x31, 0xad, 0xba, 0xf4,
		0xee, 0x4b, 0xcd, 0xeb, 0xd6, 0xd9, 0x6e, 0xb7, 0x07, 0xf4, 0x5f, 0x7d,
		0x23, 0x44, 0xb5, 0x19, 0xb3, 0x20, 0xd9, 0x1d, 0x10, 0xab, 0x23, 0x93,
		0x92, 0xbb, 0x59, 0x5c, 0x27, 0x2f, 0xb4, 0xea, 0xa5, 0x53, 0x51, 0x1d,
		0x1b, 0x03, 0x46, 0xad, 0x5e, 0xf0, 0x74, 0xd0, 0x97, 0x85, 0xa8, 0x84,
		0xff, 0x51, 0xed, 0x6b, 0x43, 0xcc, 0x5e, 0xd7, 0x56, 0xfc, 0xa8, 0x03,
		0x73, 0x18, 0x3f, 0x3d, 0xe5, 0x6b, 0xf3, 0x6f, 0x79, 0x1b, 0x2b, 0x1f,
		0xea, 0x0d, 0x9b, 0xf3, 0x8e, 0x5b, 0x71, 0x48, 0xaf, 0x2e, 0xa7, 0xfd,
		0x9a, 0x1c, 0xde, 0xb2, 0x90, 0xbc, 0x14, 0xe4, 0xe9, 0x5a, 0x1e, 0xc5,
		0xe4, 0xea, 0xa5, 0xc3, 0x3c, 0xa7, 0x7e, 0x91, 0x57, 0x19, 0x9e, 0xe4,
		0x6e, 0xd9, 0xa5, 0x2f, 0xbb, 0x41, 0x67, 0x90, 0xba, 0xab, 0x31, 0xb9,
		0x9a, 0xb1, 0xe4, 0x3e, 0x95, 0x5f, 0x7b, 0x50, 0x2b, 0x96, 0xbc, 0x1a,
		0xf5, 0x59, 0xe8, 0xa3, 0x7b, 0xe2, 0xb6, 0x46, 0x2e, 0xf8, 0x69, 0xcc,
		0xf8, 0x8e, 0xd9, 0x6c, 0x4f, 0x3d, 0xdf, 0xdc, 0xf4, 0x3d, 0x87, 0x4a,
		0x5d, 0x9e, 0x2e, 0xe9, 0xb3, 0xab, 0x9e, 0x04, 0xc5, 0x3c, 0xf5, 0x86,
		0x94, 0x1a, 0x3f, 0x52, 0xe0, 0x22, 0xa9, 0xba, 0x7e, 0xd5, 0xcc, 0x9a,
		0xdf, 0xc8, 0x68, 0x2a, 0xb4, 0x6a, 0x71, 0x7e, 0x67, 0x77, 0x38, 0xb0,
		0x5d, 0xe5, 0x07, 0xe5, 0x91, 0xb1, 0x2d, 0x9f, 0x1c, 0xea, 0x96, 0x7e,
		0x33, 0x6f, 0x65, 0x83, 0xf8, 0xab, 0x2d, 0x17, 0xe9, 0xf3, 0x92, 0x34,
		0xf3, 0xf1, 0xfa, 0xa4, 0x05, 0x16, 0xf2, 0x9a, 0x36, 0xa9, 0x96, 0x07,
		0x13, 0xf3, 0x01, 0x75, 0x95, 0x49, 0x5e, 0xf2, 0x61, 0xc6, 0x33, 0x79,
		0xd9, 0xe5, 0x41, 0xd2, 0x39, 0x19, 0xf5, 0x7b, 0x4d, 0xee, 0xe1, 0x72,
		0xa7, 0x7e, 0x3c, 0xff, 0xa0, 0x56, 0x4a, 0x39, 0x5f, 0x75, 0x8b, 0xcd,
		0x43, 0x0a, 0x4e, 0x71, 0xf4, 0x3e, 0x26, 0x66, 0xb3, 0xa6, 0x66, 0x3a,
		0xc3, 0x35, 0x42, 0xd6, 0xd3, 0xd5, 0x9d, 0x86, 0xe3, 0x70, 0x4d, 0x15,
		0x0c, 0x3e, 0x83, 0xfb, 0xf0, 0x0e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 0xf2, 0x0d, 0xcb, 0x59, 0xb8,
		0xf2, 0x40, 0x72, 0x52, 0xc5, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58,
		0x74, 0x52, 0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65,
		0x20, 0x74, 0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00,
		0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f,
		0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b,
		0x13, 0x23, 0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34,
		0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4,
		0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00,
		0xea, 0x17, 0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00,
		0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func appleTouchIcon152x152Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x98, 0x00, 0x00, 0x00, 0x98,
		0x04, 0x03, 0x00, 0x00, 0x00, 0xea, 0xec, 0x3d, 0x12, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x1e, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0xdc, 0xec, 0xf0, 0x1f, 0x28, 0x2b, 0x4e, 0x59, 0x5c, 0xd0, 0xe0,
		0xe5, 0x3e, 0x48, 0x4c, 0xa5, 0xb2, 0xb7, 0x91, 0x9e, 0xa2, 0x72, 0x7e,
		0x82, 0xbf, 0xce, 0xd3, 0x51, 0x10, 0x97, 0xf1, 0x00, 0x00, 0x00, 0x09,
		0x70, 0x48, 0x59, 0x73, 0x00, 0x00, 0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13,
		0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00, 0x00, 0x01, 0xb1, 0x49, 0x44, 0x41,
		0x54, 0x68, 0xde, 0xed, 0x97, 0xc1, 0x4b, 0xc3, 0x30, 0x14, 0x87, 0x43,
		0xc6, 0xd4, 0xeb, 0x83, 0x32, 0xdc, 0x2d, 0x64, 0xec, 0x3e, 0x56, 0x06,
		0xf3, 0x38, 0x0c, 0xb2, 0xdd, 0x8a, 0x75, 0x52, 0x6f, 0x0a, 0xe2, 0xf4,
		0xa6, 0xe8, 0xc0, 0xdd, 0xd4, 0xd6, 0xda, 0xeb, 0x50, 0x36, 0xfa, 0xdf,
		0x9a, 0xa6, 0x2a, 0xc8, 0x0e, 0x09, 0xeb, 0x63, 0x4c, 0x79, 0xdf, 0x69,
		0x87, 0xc7, 0xd7, 0xac, 0x79, 0xef, 0x97, 0x86, 0x31, 0x82, 0x20, 0x08,
		0x82, 0x20, 0x08, 0x82, 0x20, 0x08, 0x82, 0xf8, 0x63, 0x48, 0x83, 0xbd,
		0x8e, 0xbb, 0xd4, 0x85, 0xbe, 0xa6, 0x67, 0x97, 0x99, 0x3a, 0xdf, 0xf2,
		0xc0, 0x3b, 0x55, 0x70, 0x6c, 0x5d, 0xd8, 0xb3, 0xa9, 0xeb, 0x5a, 0x64,
		0xa0, 0xf1, 0xec, 0x32, 0x53, 0x07, 0x1b, 0x96, 0x29, 0x35, 0xb2, 0xcb,
		0x12, 0xa5, 0x06, 0x0e, 0xb2, 0x86, 0xf5, 0xc5, 0x7e, 0x6d, 0x40, 0xe2,
		0x22, 0xe3, 0x8e, 0xad, 0x71, 0xe2, 0x22, 0x73, 0xec, 0x48, 0x4e, 0xb2,
		0x8d, 0xc9, 0x24, 0x1b, 0x8f, 0x03, 0x26, 0x71, 0x64, 0xd1, 0x2c, 0xcf,
		0xf3, 0x49, 0x1c, 0x60, 0xc8, 0xa2, 0xb9, 0x99, 0x1d, 0xef, 0x1a, 0x41,
		0xd6, 0xba, 0x80, 0x92, 0x06, 0x82, 0xec, 0x14, 0x10, 0x65, 0x7a, 0xf6,
		0x97, 0xb1, 0x9f, 0xcd, 0x06, 0x08, 0xb2, 0xd6, 0x00, 0x86, 0x81, 0x94,
		0x82, 0xf5, 0x17, 0xd5, 0x65, 0x7b, 0x00, 0xb7, 0xe6, 0x87, 0x08, 0xab,
		0xcb, 0x76, 0xc1, 0xeb, 0xa2, 0x35, 0xed, 0x0e, 0x34, 0x83, 0xed, 0x94,
		0xe9, 0xbf, 0xf9, 0x82, 0x26, 0xd3, 0x1b, 0xf0, 0xce, 0xb1, 0x64, 0xba,
		0x35, 0xbc, 0x29, 0x93, 0x48, 0xa9, 0xa1, 0x9b, 0xd6, 0x9b, 0xc4, 0x2b,
		0xba, 0xb5, 0x64, 0xdc, 0x8c, 0x93, 0x5a, 0xf6, 0x38, 0xc6, 0xca, 0xda,
		0x0f, 0x66, 0x32, 0x9b, 0x53, 0x94, 0x3c, 0xab, 0x5d, 0x96, 0xb6, 0x27,
		0x94, 0x70, 0xac, 0xa5, 0x1f, 0x85, 0x6d, 0x88, 0x22, 0xe3, 0x22, 0x4c,
		0x75, 0x40, 0xfe, 0x1e, 0xab, 0xf5, 0x0f, 0x14, 0xc9, 0xfa, 0xda, 0x76,
		0x8e, 0x75, 0x3a, 0x09, 0xbd, 0xa9, 0x87, 0x02, 0xeb, 0xa8, 0xd3, 0xcd,
		0xbb, 0x8f, 0x26, 0x6b, 0xcf, 0x11, 0x65, 0x75, 0x14, 0x99, 0xf8, 0x59,
		0xd9, 0xb0, 0xb2, 0x2c, 0xea, 0x88, 0xef, 0xf4, 0xa8, 0xbc, 0x01, 0xfc,
		0xe0, 0xe8, 0xb5, 0xf8, 0xe8, 0x67, 0x09, 0x42, 0x6b, 0xf0, 0x33, 0x18,
		0x3d, 0xfa, 0x63, 0x3f, 0xd5, 0x49, 0xd4, 0x41, 0x90, 0x01, 0x8c, 0x72,
		0x85, 0x32, 0x4e, 0x46, 0x86, 0x35, 0xe8, 0x3c, 0x2a, 0x33, 0x03, 0xbc,
		0x7b, 0x84, 0x08, 0x12, 0xe1, 0xdb, 0x8d, 0x02, 0xb5, 0x88, 0x51, 0xc2,
		0x51, 0x8a, 0xba, 0xbe, 0x1a, 0x04, 0x7c, 0xad, 0xd8, 0x5e, 0xbd, 0x07,
		0x14, 0xad, 0x21, 0x56, 0xae, 0x92, 0x2e, 0xb2, 0x66, 0x96, 0x65, 0xf6,
		0x0f, 0xda, 0x7e, 0x96, 0x25, 0x1b, 0xbf, 0x88, 0x6d, 0xa9, 0x2c, 0xbd,
		0x2a, 0x08, 0xac, 0xb2, 0xb2, 0xce, 0xfa, 0x50, 0x82, 0x20, 0x08, 0x82,
		0x20, 0x08, 0x82, 0x20, 0x08, 0x82, 0xf8, 0xcf, 0x7c, 0x02, 0xaa, 0xe6,
		0x8c, 0x17, 0x11, 0x81, 0x67, 0x8a, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54,
		0x58, 0x74, 0x52, 0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c,
		0x65, 0x20, 0x74, 0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00,
		0x00, 0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca,
		0x4f, 0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63,
		0x0b, 0x13, 0x23, 0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80,
		0x34, 0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8,
		0xc4, 0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e,
		0x00, 0xea, 0x17, 0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00,
		0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func appleTouchIcon144x144Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00, 0x90,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x15, 0x68, 0xff, 0x8b, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x1b, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0xdc, 0xec, 0xf0, 0x50, 0x5b, 0x5e, 0xb6, 0xc4, 0xc8, 0xd4, 0xe4,
		0xe9, 0x2e, 0x38, 0x3b, 0xa8, 0xb6, 0xba, 0x67, 0x72, 0x76, 0x86, 0x92,
		0x96, 0xd3, 0x99, 0xc6, 0x9f, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59,
		0x73, 0x00, 0x00, 0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a,
		0x9c, 0x18, 0x00, 0x00, 0x01, 0x6e, 0x49, 0x44, 0x41, 0x54, 0x68, 0xde,
		0xed, 0x97, 0x4d, 0x6b, 0xc2, 0x40, 0x10, 0x86, 0x25, 0x60, 0x93, 0xeb,
		0x90, 0xc5, 0xb3, 0x1f, 0xfd, 0xf0, 0x9a, 0x2a, 0xe2, 0x75, 0xeb, 0xd2,
		0x5e, 0x17, 0x4b, 0xf0, 0x5a, 0x51, 0x42, 0x8f, 0x6d, 0xd4, 0xa6, 0xc7,
		0x2a, 0x14, 0xf3, 0xb3, 0xbb, 0x49, 0x73, 0x69, 0x0f, 0x6e, 0xc8, 0x2c,
		0xc5, 0xc2, 0xfb, 0x9c, 0x87, 0x07, 0xb2, 0x3b, 0xf3, 0x6e, 0xa6, 0xd5,
		0x02, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x0f, 0x18, 0x8c,
		0x0c, 0x13, 0x5d, 0xa7, 0x6a, 0x7a, 0xb2, 0xa4, 0x47, 0x86, 0xd0, 0x26,
		0x7a, 0x2d, 0xaa, 0x3a, 0x27, 0x4b, 0x2e, 0x1d, 0x8a, 0x94, 0x9a, 0xd9,
		0x44, 0x5b, 0xa5, 0xa4, 0x55, 0x14, 0x66, 0x59, 0x6a, 0x3b, 0xc9, 0x45,
		0x96, 0xed, 0xed, 0x22, 0x5d, 0xeb, 0x56, 0x7a, 0x10, 0x9d, 0xb9, 0x68,
		0x6e, 0x3a, 0xe2, 0x8a, 0x2f, 0x6a, 0x0f, 0xc7, 0x44, 0x62, 0x76, 0xec,
		0x72, 0x45, 0xd7, 0x92, 0x4a, 0x6e, 0x99, 0x22, 0x2f, 0xfa, 0xf6, 0xd0,
		0x1d, 0x53, 0xf4, 0x68, 0x86, 0x38, 0x49, 0x46, 0x92, 0x2d, 0xda, 0x53,
		0x98, 0xea, 0x56, 0x7c, 0xb3, 0x66, 0x8a, 0xda, 0x51, 0x75, 0x38, 0xde,
		0x8e, 0x27, 0xf2, 0x24, 0xbd, 0x38, 0xe9, 0x23, 0x9f, 0x44, 0xf7, 0xbc,
		0x44, 0xe6, 0xd3, 0x3e, 0xdc, 0x88, 0x22, 0x7a, 0x70, 0x33, 0x6b, 0x4b,
		0x12, 0x07, 0xed, 0x42, 0x64, 0x9e, 0x03, 0xf1, 0x9c, 0x6a, 0xbe, 0xc8,
		0x2f, 0x46, 0x4d, 0x4d, 0x77, 0xfc, 0xe9, 0xdf, 0x94, 0x93, 0x36, 0xfb,
		0xe4, 0xc7, 0xc8, 0xa6, 0x1c, 0xff, 0x90, 0x1d, 0x23, 0x26, 0x90, 0x56,
		0xd2, 0x41, 0x8c, 0x14, 0xc4, 0x45, 0xb6, 0x75, 0xb4, 0x8b, 0xcc, 0x5e,
		0x44, 0xbf, 0x3a, 0xbc, 0x71, 0xf8, 0x0f, 0xe8, 0x67, 0x87, 0x37, 0x16,
		0x05, 0x44, 0x4f, 0x4e, 0x44, 0xfe, 0xd9, 0x88, 0xbc, 0xea, 0x88, 0x2f,
		0xb8, 0x67, 0x14, 0x4c, 0xcb, 0xa7, 0xb1, 0xbd, 0xe5, 0xde, 0x5a, 0x40,
		0xf7, 0x87, 0x38, 0x9e, 0xbf, 0x49, 0x6e, 0x1f, 0x99, 0xdb, 0x12, 0xa3,
		0x64, 0x2c, 0xd9, 0x9d, 0x1d, 0x54, 0xcf, 0x23, 0x7b, 0xd6, 0xfc, 0x75,
		0xe5, 0x61, 0x4f, 0xff, 0xfc, 0x7d, 0xa5, 0x84, 0x9a, 0xa4, 0x0e, 0x7e,
		0x6b, 0xe2, 0x7e, 0xbf, 0xdf, 0x24, 0x21, 0xeb, 0xed, 0x1a, 0x76, 0x91,
		0xc8, 0xf3, 0xa3, 0xcd, 0x32, 0xcc, 0xf3, 0xe5, 0x1f, 0xae, 0x10, 0x6e,
		0x44, 0xce, 0xb6, 0x23, 0xb3, 0x65, 0x18, 0x6a, 0xec, 0x22, 0x35, 0x36,
		0x16, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x0c, 0xbe, 0x00,
		0xcc, 0x88, 0x62, 0x15, 0xd0, 0x67, 0xc8, 0x90, 0x00, 0x00, 0x00, 0x57,
		0x7a, 0x54, 0x58, 0x74, 0x52, 0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66,
		0x69, 0x6c, 0x65, 0x20, 0x74, 0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74,
		0x63, 0x00, 0x00, 0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28,
		0x28, 0xca, 0x4f, 0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b,
		0x2e, 0x63, 0x0b, 0x13, 0x23, 0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20,
		0x44, 0x80, 0x34, 0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8,
		0xd4, 0xc8, 0xc4, 0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0,
		0x4a, 0x2e, 0x00, 0xea, 0x17, 0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00,
		0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func appleTouchIcon120x120Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x78, 0x00, 0x00, 0x00, 0x78,
		0x04, 0x03, 0x00, 0x00, 0x00, 0xcb, 0x4a, 0x2b, 0xe1, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x24, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0xdd, 0xee, 0xf2, 0xd9, 0xe9, 0xed, 0x1f, 0x28, 0x2b, 0x7f, 0x8b,
		0x8f, 0xc7, 0xd6, 0xdb, 0x50, 0x5b, 0x5f, 0x39, 0x43, 0x46, 0x9f, 0xad,
		0xb1, 0x2b, 0x35, 0x38, 0xb5, 0xc3, 0xc8, 0x62, 0x6d, 0x71, 0x91, 0x09,
		0x9f, 0xe5, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00,
		0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00,
		0x00, 0x01, 0x90, 0x49, 0x44, 0x41, 0x54, 0x58, 0xc3, 0xed, 0x96, 0xcf,
		0x4b, 0x02, 0x51, 0x10, 0x80, 0x85, 0x17, 0x6d, 0xd6, 0xe9, 0x0d, 0x04,
		0x5d, 0xdf, 0xa3, 0xed, 0xd2, 0x65, 0xe1, 0x45, 0xe2, 0xb5, 0xac, 0xbc,
		0xae, 0xb4, 0xd4, 0xdd, 0x5f, 0xe5, 0xc9, 0x43, 0xec, 0xa1, 0x9b, 0x64,
		0x05, 0x7a, 0x59, 0x28, 0x28, 0xbd, 0x29, 0x66, 0xb5, 0xd7, 0xc4, 0x10,
		0xff, 0xb9, 0xde, 0x7a, 0x5b, 0xe8, 0xad, 0x3a, 0xd4, 0xa5, 0xe6, 0xbb,
		0x8e, 0x1f, 0x8b, 0x33, 0xf3, 0x66, 0x26, 0x95, 0x22, 0x08, 0x82, 0x20,
		0x08, 0x82, 0x20, 0x7e, 0x82, 0x8e, 0x26, 0x30, 0x87, 0xd3, 0x51, 0xdc,
		0x14, 0xb4, 0x5a, 0x61, 0x18, 0x0e, 0x1d, 0xa3, 0xbc, 0xa6, 0xc3, 0xe1,
		0x87, 0x49, 0x76, 0x39, 0xe7, 0x3b, 0x66, 0x79, 0x5d, 0x87, 0xf9, 0xa1,
		0x51, 0x96, 0xf3, 0x64, 0x10, 0x09, 0x72, 0x33, 0x77, 0x62, 0x96, 0x37,
		0x72, 0x39, 0x37, 0x49, 0x2e, 0xce, 0x49, 0x69, 0xe3, 0xef, 0xcb, 0x4c,
		0x29, 0x85, 0x95, 0x1d, 0x7f, 0x3a, 0xae, 0x06, 0x0e, 0x4e, 0x2e, 0xbd,
		0x48, 0x69, 0xbf, 0x4d, 0x50, 0xf2, 0x63, 0xd4, 0x71, 0xf1, 0xb6, 0x59,
		0x5c, 0x3e, 0x00, 0xb0, 0x0b, 0x82, 0xef, 0x62, 0xe4, 0x7d, 0x17, 0xda,
		0xd5, 0xca, 0xe8, 0x16, 0x25, 0xaf, 0xc0, 0xf6, 0x83, 0xce, 0xf6, 0xd3,
		0x31, 0x46, 0xee, 0xf2, 0xb3, 0x48, 0x63, 0xa8, 0x52, 0x75, 0xf9, 0x3b,
		0xbe, 0x49, 0xba, 0xfc, 0x15, 0x2f, 0x3f, 0xeb, 0xff, 0x8c, 0x96, 0xf7,
		0x24, 0xdc, 0x05, 0x0a, 0x29, 0x5b, 0x3d, 0x61, 0x0f, 0xc6, 0xb1, 0xee,
		0x5c, 0x5c, 0x66, 0x35, 0x2e, 0xb8, 0x3d, 0xb8, 0xc4, 0xf5, 0xb6, 0x75,
		0x24, 0x40, 0xf0, 0xf3, 0x3a, 0xee, 0x61, 0x58, 0xf9, 0xbe, 0x00, 0x3e,
		0x44, 0xbe, 0xe7, 0xac, 0x9f, 0x77, 0xe5, 0x56, 0x80, 0x9c, 0x24, 0x2c,
		0x7b, 0x21, 0xa1, 0x88, 0x1e, 0x43, 0x99, 0xd8, 0xb4, 0x5d, 0x76, 0x86,
		0x35, 0xc4, 0x0d, 0xa6, 0x54, 0xdf, 0xfc, 0x7e, 0x51, 0x99, 0xf9, 0xb3,
		0xe6, 0xcc, 0xf4, 0x24, 0x46, 0xae, 0xb5, 0x03, 0xa5, 0x9c, 0x2b, 0xb9,
		0x89, 0x48, 0x18, 0x2b, 0xc3, 0x60, 0x5a, 0x19, 0xf5, 0x01, 0x53, 0x2a,
		0x56, 0xe6, 0x5c, 0x4a, 0x01, 0x70, 0x8f, 0x68, 0x12, 0x76, 0x2d, 0xa2,
		0xd9, 0x09, 0xa7, 0xa8, 0xf6, 0xb4, 0x4a, 0xad, 0x82, 0xf4, 0x9a, 0x75,
		0xdc, 0xc6, 0x70, 0x2c, 0xbf, 0x52, 0x5d, 0xe2, 0x49, 0x4e, 0xe2, 0x07,
		0x8d, 0xce, 0x76, 0xfc, 0xa0, 0x49, 0x94, 0x3d, 0x2f, 0xe9, 0xa0, 0xf1,
		0x3c, 0x21, 0x7e, 0xeb, 0x26, 0x91, 0x32, 0x49, 0x06, 0x5d, 0x3a, 0x93,
		0x9c, 0x9e, 0x6a, 0x3e, 0xcd, 0x9b, 0x7d, 0x35, 0x8a, 0xd7, 0x4d, 0x51,
		0xbd, 0x5c, 0x94, 0xf9, 0xc3, 0xb3, 0x55, 0x9f, 0x14, 0x27, 0x08, 0x82,
		0x20, 0x08, 0x82, 0xf8, 0x67, 0x7c, 0x01, 0xfd, 0x7b, 0x96, 0x6b, 0x8e,
		0x4b, 0x8f, 0x2a, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52,
		0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74,
		0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c,
		0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc,
		0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23,
		0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64,
		0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4,
		0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17,
		0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
		0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func appleTouchIcon114x114Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x72, 0x00, 0x00, 0x00, 0x72,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x7d, 0xf3, 0x98, 0x4e, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x24, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0xd9, 0xe9, 0xee, 0xde, 0xee, 0xf2, 0x2b, 0x34, 0x37, 0xac, 0xba,
		0xbf, 0x61, 0x6b, 0x70, 0x98, 0xa5, 0xa9, 0x50, 0x5b, 0x5f, 0xbe, 0xcd,
		0xd2, 0x41, 0x4b, 0x4e, 0x73, 0x7e, 0x82, 0x88, 0x94, 0x98, 0x20, 0x3c,
		0x31, 0x6d, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00,
		0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00,
		0x00, 0x01, 0x4b, 0x49, 0x44, 0x41, 0x54, 0x58, 0xc3, 0xed, 0x95, 0xbf,
		0x4b, 0xc3, 0x40, 0x14, 0xc7, 0x0b, 0x87, 0x43, 0xc7, 0x3b, 0x4a, 0xa9,
		0xe3, 0x3d, 0x44, 0x02, 0x5d, 0x0e, 0x8e, 0x5a, 0xb5, 0x53, 0x6a, 0x40,
		0xb1, 0x8b, 0x4b, 0x06, 0x47, 0x41, 0xb4, 0xe0, 0x14, 0xc4, 0xa1, 0x38,
		0x15, 0x1c, 0x62, 0xbb, 0x54, 0x54, 0x90, 0x4e, 0x66, 0xa8, 0xc2, 0x8d,
		0x56, 0x0a, 0xfa, 0xd7, 0x79, 0xe9, 0xe4, 0x72, 0xa7, 0xf7, 0xa8, 0x8b,
		0xbc, 0xcf, 0x98, 0x2f, 0x1f, 0x42, 0xde, 0x8f, 0xbc, 0x4a, 0x85, 0x20,
		0x08, 0x82, 0x20, 0x08, 0xe2, 0x2f, 0x61, 0xda, 0x82, 0x4a, 0x1f, 0xf2,
		0x3c, 0x1f, 0x39, 0xcd, 0x32, 0x1d, 0x3b, 0xb2, 0x0c, 0x00, 0x9a, 0x4e,
		0xf3, 0xce, 0xa6, 0x9b, 0x2e, 0x93, 0x73, 0xee, 0x31, 0x6d, 0xea, 0x34,
		0xc5, 0xc8, 0xbc, 0x3a, 0xcd, 0x5d, 0xf3, 0xe2, 0x31, 0xf7, 0xbc, 0x15,
		0x5c, 0xfb, 0xaf, 0x26, 0xd3, 0x0a, 0x67, 0x4e, 0x4f, 0x93, 0xb3, 0xd9,
		0x04, 0x61, 0x76, 0x86, 0xb6, 0xf7, 0x7c, 0xac, 0x82, 0xcd, 0x6a, 0x0c,
		0x25, 0x1b, 0xe1, 0xe6, 0x96, 0x8c, 0x2e, 0xcc, 0x22, 0x46, 0x98, 0x19,
		0xec, 0x5b, 0xa9, 0xbd, 0x08, 0x37, 0x0b, 0x79, 0xb4, 0xac, 0x6f, 0x78,
		0x85, 0xde, 0xa2, 0x09, 0xb2, 0x9f, 0x78, 0xb3, 0xe0, 0x73, 0xa4, 0x99,
		0x41, 0xfd, 0x12, 0x67, 0x76, 0x04, 0xdc, 0x7c, 0xde, 0x63, 0x4c, 0x76,
		0x02, 0x20, 0x6b, 0x1f, 0x98, 0xb9, 0x6d, 0x95, 0x43, 0x14, 0xcd, 0x31,
		0x13, 0xdf, 0x7e, 0x1f, 0x82, 0xa8, 0x2b, 0xd4, 0x96, 0x3d, 0xf6, 0xb9,
		0x7c, 0xc6, 0x6d, 0x76, 0xb5, 0xfb, 0xed, 0x59, 0xd8, 0x3f, 0x21, 0x83,
		0x5b, 0xa4, 0xb9, 0x0d, 0xeb, 0x48, 0xf3, 0x29, 0xfc, 0x9d, 0x6c, 0xb6,
		0x2c, 0x6a, 0x11, 0xfe, 0x9d, 0x2c, 0xee, 0x0d, 0xb4, 0xbe, 0x16, 0x3c,
		0xb8, 0xb6, 0xac, 0x0b, 0x8d, 0xe4, 0x80, 0x43, 0x78, 0x3f, 0xad, 0x59,
		0x22, 0x11, 0x33, 0x34, 0xed, 0x73, 0x21, 0x1b, 0xe7, 0x0a, 0x31, 0x7d,
		0x3b, 0x57, 0xc6, 0x0c, 0x7e, 0xbd, 0x2b, 0x4c, 0xb9, 0x8f, 0x83, 0xf6,
		0x99, 0xb5, 0xe4, 0xd0, 0x7d, 0xed, 0x6d, 0xbd, 0xdc, 0x37, 0xfb, 0x87,
		0x6b, 0xcf, 0x57, 0x7f, 0xed, 0x5b, 0x69, 0x9a, 0x1e, 0x3b, 0x4d, 0x7f,
		0x4a, 0x10, 0x04, 0x41, 0x10, 0x04, 0xb1, 0x0a, 0xbe, 0x00, 0x67, 0x7c,
		0x62, 0xc4, 0x79, 0xbc, 0xe0, 0xe0, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54,
		0x58, 0x74, 0x52, 0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c,
		0x65, 0x20, 0x74, 0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00,
		0x00, 0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca,
		0x4f, 0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63,
		0x0b, 0x13, 0x23, 0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80,
		0x34, 0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8,
		0xc4, 0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e,
		0x00, 0xea, 0x17, 0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00,
		0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func appleTouchIcon76x76Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x4c, 0x00, 0x00, 0x00, 0x4c,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x35, 0xb9, 0x4c, 0x18, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x27, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0x20, 0x29, 0x2c, 0xdf, 0xee, 0xf3, 0x89, 0x95, 0x99, 0x41, 0x4c,
		0x4f, 0xcd, 0xdd, 0xe1, 0x28, 0x31, 0x34, 0x2d, 0x36, 0x39, 0xb7, 0xc5,
		0xca, 0xaf, 0xbd, 0xc1, 0x70, 0x7c, 0x80, 0x99, 0xa6, 0xaa, 0x50, 0x5a,
		0x5e, 0x12, 0xbd, 0x83, 0x64, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59,
		0x73, 0x00, 0x00, 0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a,
		0x9c, 0x18, 0x00, 0x00, 0x00, 0xef, 0x49, 0x44, 0x41, 0x54, 0x48, 0xc7,
		0x63, 0x60, 0x18, 0x05, 0xa3, 0x60, 0x14, 0x0c, 0x15, 0xc0, 0x28, 0x28,
		0x28, 0x40, 0x84, 0x58, 0x96, 0xb1, 0xb1, 0x39, 0xba, 0x18, 0x17, 0xa6,
		0x58, 0xa6, 0x92, 0x52, 0x08, 0xba, 0x32, 0x2c, 0x62, 0x99, 0xaa, 0x9b,
		0xb1, 0x98, 0xd6, 0x84, 0xa1, 0x4c, 0xa3, 0x10, 0x8b, 0x83, 0x8d, 0x28,
		0x57, 0x26, 0x08, 0x04, 0x84, 0x95, 0x09, 0x78, 0x19, 0xaf, 0x3a, 0x4e,
		0x50, 0x19, 0x63, 0x71, 0x90, 0x92, 0x52, 0x74, 0x21, 0x21, 0x65, 0x6c,
		0x9b, 0x34, 0x76, 0xef, 0x88, 0x20, 0xa8, 0x4c, 0x26, 0xc8, 0x9c, 0x21,
		0xfd, 0x54, 0x01, 0x21, 0x65, 0x52, 0xaa, 0x8e, 0xc0, 0x58, 0x62, 0x20,
		0x42, 0x99, 0x00, 0x11, 0x01, 0x22, 0x13, 0x34, 0xa7, 0x40, 0x90, 0xb0,
		0x32, 0x36, 0x23, 0xd5, 0xd9, 0x4b, 0x12, 0x09, 0x07, 0x48, 0x55, 0x93,
		0x92, 0xea, 0x16, 0x01, 0x82, 0xc1, 0x2b, 0xe8, 0x65, 0x19, 0xa4, 0xe9,
		0x48, 0x44, 0x64, 0x89, 0x9f, 0x56, 0x5a, 0x48, 0x44, 0xd4, 0x33, 0x8a,
		0x04, 0x6d, 0x20, 0xe8, 0x05, 0xa0, 0x37, 0x89, 0x50, 0x26, 0x65, 0x92,
		0x28, 0x58, 0x4c, 0xd8, 0x52, 0x61, 0xd5, 0xc9, 0xc6, 0x93, 0x34, 0x08,
		0x7a, 0x41, 0x0a, 0x98, 0x40, 0xf0, 0x06, 0x08, 0x44, 0x84, 0xcd, 0x67,
		0xf1, 0xe6, 0x35, 0x89, 0xd0, 0x0c, 0x88, 0x45, 0xd9, 0x99, 0x63, 0xe8,
		0x89, 0x97, 0xe5, 0xcc, 0xa6, 0x10, 0xf2, 0x32, 0x60, 0x76, 0x47, 0xc7,
		0x14, 0x74, 0x65, 0xc9, 0x98, 0x62, 0xec, 0xe5, 0xe5, 0x05, 0xe8, 0x19,
		0x8b, 0x0d, 0x8b, 0x18, 0x96, 0x32, 0x04, 0xab, 0xd8, 0x28, 0x18, 0x05,
		0xa3, 0x80, 0xee, 0x00, 0x00, 0x17, 0x05, 0x52, 0x9c, 0x58, 0x0a, 0x3f,
		0xda, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52, 0x61, 0x77,
		0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74, 0x79, 0x70,
		0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c, 0xe3, 0xf2,
		0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc, 0x49, 0xe5,
		0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23, 0x13, 0x4b,
		0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64, 0x03, 0x23,
		0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4, 0x1c, 0xc4,
		0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17, 0x11, 0x74,
		0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44,
		0xae, 0x42, 0x60, 0x82,
	})
}

func appleTouchIcon72x72Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x48, 0x00, 0x00, 0x00, 0x48,
		0x04, 0x03, 0x00, 0x00, 0x00, 0xa7, 0xc3, 0xae, 0x74, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x21, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0x20, 0x29, 0x2c, 0x31, 0x3a, 0x3e, 0xbc, 0xca, 0xcf, 0xe0, 0xf0,
		0xf4, 0x92, 0x9f, 0xa3, 0xd2, 0xe1, 0xe6, 0x4c, 0x56, 0x5a, 0xa6, 0xb4,
		0xb8, 0x62, 0x6d, 0x71, 0x79, 0x85, 0x89, 0x47, 0x85, 0x87, 0xbd, 0x00,
		0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00, 0x0b, 0x13, 0x00,
		0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00, 0x00, 0x00, 0xf7,
		0x49, 0x44, 0x41, 0x54, 0x48, 0xc7, 0xed, 0x93, 0xb1, 0x6a, 0xc3, 0x30,
		0x10, 0x86, 0x75, 0x81, 0x52, 0xb2, 0xe9, 0x02, 0xc1, 0x78, 0x8b, 0xb5,
		0x68, 0xaf, 0x9d, 0xb4, 0x64, 0x75, 0xa2, 0x07, 0x48, 0x42, 0x5f, 0xc0,
		0x46, 0xb4, 0x5b, 0x9c, 0x45, 0x79, 0x81, 0x3a, 0x74, 0x2c, 0x85, 0xf4,
		0x01, 0x0a, 0xc5, 0x7d, 0xcb, 0x64, 0x70, 0x96, 0x3b, 0x92, 0x23, 0xbb,
		0xfe, 0x45, 0xe2, 0xe7, 0x03, 0xdd, 0xfd, 0xe2, 0x57, 0x2a, 0x2a, 0x2a,
		0xea, 0x3e, 0x01, 0x22, 0xb5, 0x90, 0x5a, 0x60, 0x8c, 0x51, 0x92, 0x05,
		0xbf, 0xf9, 0x4b, 0x46, 0xa8, 0x35, 0xb5, 0x60, 0xe3, 0x2a, 0x0a, 0xbd,
		0xfa, 0x92, 0x42, 0xcf, 0x81, 0xce, 0x64, 0xf7, 0x0c, 0x7a, 0x62, 0x83,
		0xc3, 0x98, 0x43, 0x9a, 0xed, 0x79, 0x1d, 0x82, 0x41, 0xd8, 0x81, 0x04,
		0x3d, 0xb6, 0xbe, 0xfa, 0xd4, 0xb7, 0x21, 0x38, 0xba, 0x7c, 0xb6, 0x14,
		0xa0, 0x51, 0x71, 0x30, 0xf6, 0x5f, 0x80, 0x12, 0xdf, 0x20, 0x6a, 0x25,
		0x42, 0x97, 0x35, 0x6f, 0x3e, 0x37, 0x91, 0x23, 0xf8, 0x73, 0xd3, 0x1f,
		0x31, 0x82, 0x61, 0xbb, 0x70, 0x2b, 0x2d, 0x85, 0x69, 0xbb, 0x62, 0x99,
		0x09, 0x90, 0x42, 0xbd, 0x77, 0x8d, 0x10, 0xe6, 0xf9, 0x48, 0xea, 0x2f,
		0x61, 0xbb, 0x0c, 0x31, 0xf5, 0x02, 0x94, 0xce, 0x77, 0xe6, 0xbb, 0x14,
		0x66, 0x4a, 0x17, 0x55, 0x5e, 0xbf, 0x4b, 0x7f, 0xd7, 0xcd, 0xfc, 0x74,
		0x7b, 0x35, 0xa7, 0xfe, 0xa2, 0x6d, 0x98, 0xf4, 0x8b, 0x3e, 0x30, 0xe8,
		0xed, 0x23, 0xbb, 0xd4, 0xad, 0x67, 0xba, 0x96, 0x42, 0xac, 0x1a, 0x4a,
		0x6d, 0x3c, 0x2d, 0x90, 0x0d, 0xac, 0x2d, 0x81, 0x59, 0xbc, 0xe6, 0x80,
		0xbc, 0xf9, 0x51, 0x51, 0x51, 0x82, 0x4e, 0x2a, 0x9b, 0x3c, 0x5f, 0x25,
		0x4c, 0xe1, 0xec, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52,
		0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74,
		0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c,
		0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc,
		0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23,
		0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64,
		0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4,
		0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17,
		0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45,
		0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func appleTouchIcon60x60Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x3c, 0x00, 0x00, 0x00, 0x3c,
		0x04, 0x03, 0x00, 0x00, 0x00, 0xc8, 0xd2, 0xc4, 0x41, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x27, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0x20, 0x29, 0x2c, 0x37, 0x41, 0x44, 0xda, 0xea, 0xef, 0x47, 0x51,
		0x55, 0x2b, 0x34, 0x38, 0x58, 0x64, 0x67, 0xc5, 0xd5, 0xd9, 0xb6, 0xc4,
		0xc9, 0xd1, 0xe1, 0xe5, 0x8e, 0x9a, 0x9e, 0x73, 0x7f, 0x83, 0xa8, 0xb6,
		0xba, 0x64, 0x11, 0x1d, 0x0c, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59,
		0x73, 0x00, 0x00, 0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a,
		0x9c, 0x18, 0x00, 0x00, 0x00, 0xdb, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb,
		0x63, 0x60, 0x18, 0x05, 0xa3, 0x80, 0x44, 0x20, 0x28, 0x28, 0x80, 0xc6,
		0x47, 0xe1, 0x06, 0x29, 0x05, 0x20, 0x73, 0x59, 0x95, 0x50, 0xf8, 0x42,
		0xc7, 0xcb, 0x17, 0x22, 0x4b, 0x8b, 0x95, 0x57, 0x38, 0x22, 0x4b, 0x17,
		0xf7, 0x6c, 0x44, 0x91, 0x3e, 0x31, 0x39, 0x11, 0x59, 0xba, 0xd2, 0x35,
		0x00, 0xd5, 0xb2, 0x66, 0x54, 0x69, 0xa8, 0x59, 0x8c, 0x50, 0x37, 0x89,
		0x62, 0x95, 0x66, 0x64, 0x72, 0x51, 0xc5, 0x23, 0x2d, 0xb2, 0x7c, 0xe6,
		0x8c, 0x0d, 0x38, 0xa5, 0x19, 0x35, 0x6c, 0x56, 0x1d, 0x5f, 0x80, 0x5b,
		0x7a, 0xf3, 0x52, 0x41, 0x26, 0x07, 0x3c, 0xd2, 0x1b, 0x05, 0x18, 0x05,
		0x70, 0x4b, 0x27, 0xb7, 0x05, 0xe0, 0x71, 0x39, 0x63, 0x8c, 0x65, 0xd7,
		0x26, 0xdc, 0xba, 0x19, 0x44, 0xf7, 0x14, 0x5b, 0x24, 0xe0, 0xf1, 0xb7,
		0xa8, 0xdb, 0xe1, 0x22, 0x01, 0x9c, 0xd2, 0x02, 0x0c, 0x82, 0x1a, 0x66,
		0xb8, 0xa5, 0x55, 0x05, 0x05, 0x23, 0x70, 0x4b, 0x33, 0xae, 0xd9, 0xe2,
		0xb6, 0xb8, 0x09, 0xb7, 0xf4, 0x4e, 0xcb, 0xc9, 0x16, 0x89, 0x58, 0x9d,
		0x06, 0xf6, 0x4f, 0xc8, 0xae, 0x55, 0x49, 0x02, 0x60, 0x27, 0xa2, 0x4a,
		0x17, 0xaf, 0x4e, 0x80, 0x24, 0x31, 0x48, 0x84, 0x8a, 0xec, 0x2a, 0x46,
		0xd5, 0x3d, 0x19, 0x25, 0x31, 0x49, 0xcf, 0x9c, 0x89, 0x2c, 0xcd, 0xea,
		0xe2, 0xa2, 0x80, 0x2c, 0x2d, 0xe4, 0xe2, 0x12, 0x88, 0x27, 0x21, 0x33,
		0xa2, 0x27, 0xec, 0x51, 0x30, 0x0a, 0x08, 0x03, 0x00, 0x15, 0xca, 0x46,
		0x65, 0x9b, 0x02, 0x91, 0x4b, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58,
		0x74, 0x52, 0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65,
		0x20, 0x74, 0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00,
		0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f,
		0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b,
		0x13, 0x23, 0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34,
		0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4,
		0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00,
		0xea, 0x17, 0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00,
		0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func appleTouchIcon57x57Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x39, 0x00, 0x00, 0x00, 0x39,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x7e, 0x36, 0x9e, 0xb6, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x27, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b,
		0x2e, 0x1f, 0x28, 0x2b, 0x2a, 0x34, 0x37, 0x4b, 0x56, 0x59, 0xd5, 0xe4,
		0xe9, 0xad, 0xbb, 0xc0, 0xde, 0xef, 0xf3, 0x93, 0xa0, 0xa4, 0x70, 0x7c,
		0x80, 0x36, 0x40, 0x43, 0xc0, 0xcf, 0xd4, 0x84, 0x90, 0x94, 0x61, 0x6d,
		0x71, 0xe6, 0xed, 0x87, 0xbb, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59,
		0x73, 0x00, 0x00, 0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a,
		0x9c, 0x18, 0x00, 0x00, 0x00, 0xb9, 0x49, 0x44, 0x41, 0x54, 0x38, 0xcb,
		0x63, 0x60, 0x18, 0x05, 0xa3, 0x00, 0x1f, 0x60, 0x9a, 0x39, 0x09, 0x0f,
		0x97, 0x7b, 0xd5, 0x72, 0x05, 0x24, 0xae, 0x34, 0x2a, 0x97, 0x3d, 0x2b,
		0x1a, 0x99, 0xcb, 0x11, 0x9a, 0x8a, 0x22, 0x9b, 0x81, 0x6a, 0x13, 0xb3,
		0x2b, 0xaa, 0xac, 0x00, 0x98, 0x66, 0x14, 0x14, 0x04, 0xd3, 0xc2, 0x58,
		0x65, 0x99, 0x4f, 0x1c, 0x9e, 0x80, 0x53, 0x96, 0x69, 0x8b, 0x8b, 0x4b,
		0x10, 0x4e, 0x59, 0x89, 0xd4, 0xc3, 0xa7, 0x8b, 0x70, 0xca, 0xaa, 0x3a,
		0x0b, 0x0a, 0x2a, 0xe0, 0x93, 0x65, 0xc0, 0xed, 0x2a, 0x89, 0xac, 0x3d,
		0x13, 0x04, 0x70, 0xbb, 0x6a, 0x57, 0xca, 0x72, 0x03, 0xdc, 0x3e, 0xe2,
		0x3c, 0xbe, 0x6c, 0xb1, 0x00, 0x4e, 0x59, 0x46, 0x81, 0xa9, 0x19, 0xb8,
		0x65, 0x05, 0x19, 0xa4, 0xb3, 0x71, 0xca, 0x6a, 0x77, 0xce, 0xb4, 0xf2,
		0xc1, 0x29, 0xab, 0x9a, 0xb2, 0xca, 0x65, 0x13, 0x36, 0x57, 0x81, 0x3d,
		0xca, 0xdc, 0x1e, 0xba, 0x19, 0x24, 0xcc, 0x88, 0x26, 0x9b, 0xde, 0x03,
		0x71, 0x14, 0x03, 0x23, 0x58, 0x55, 0x37, 0x8a, 0xac, 0xb8, 0x0b, 0x0a,
		0x57, 0x1a, 0x95, 0xcb, 0x69, 0x6c, 0xc9, 0x80, 0xc2, 0x35, 0x46, 0x49,
		0x0c, 0xd0, 0x58, 0xc7, 0xc1, 0x1d, 0x05, 0x23, 0x12, 0x00, 0x00, 0xe9,
		0x96, 0x2f, 0x29, 0x5c, 0x3e, 0x13, 0x23, 0x00, 0x00, 0x00, 0x57, 0x7a,
		0x54, 0x58, 0x74, 0x52, 0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69,
		0x6c, 0x65, 0x20, 0x74, 0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63,
		0x00, 0x00, 0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28,
		0xca, 0x4f, 0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e,
		0x63, 0x0b, 0x13, 0x23, 0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44,
		0x80, 0x34, 0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4,
		0xc8, 0xc4, 0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a,
		0x2e, 0x00, 0xea, 0x17, 0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00,
		0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func appleTouchIconPng(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0xb4, 0x00, 0x00, 0x00, 0xb4,
		0x04, 0x03, 0x00, 0x00, 0x00, 0xcf, 0xe3, 0x1b, 0x01, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00,
		0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00,
		0x00, 0x00, 0x1e, 0x50, 0x4c, 0x54, 0x45, 0x22, 0x2b, 0x2e, 0xdc, 0xec,
		0xf0, 0x1e, 0x27, 0x2a, 0x35, 0x3e, 0x42, 0x5a, 0x64, 0x67, 0xa1, 0xae,
		0xb3, 0xcb, 0xda, 0xdf, 0x72, 0x7e, 0x82, 0x8a, 0x96, 0x9a, 0xb3, 0xc1,
		0xc6, 0x85, 0x9e, 0x8f, 0xb6, 0x00, 0x00, 0x01, 0xec, 0x49, 0x44, 0x41,
		0x54, 0x68, 0xde, 0xed, 0x98, 0x4d, 0x4b, 0x03, 0x31, 0x10, 0x86, 0x43,
		0xb6, 0x52, 0xaf, 0x81, 0x36, 0xda, 0xdb, 0x92, 0x15, 0xbc, 0x2e, 0xba,
		0x55, 0xbc, 0x55, 0x5b, 0xc5, 0xa3, 0x82, 0xf5, 0xe3, 0x28, 0xe2, 0xc7,
		0x51, 0x51, 0x49, 0xbd, 0x29, 0x55, 0x8b, 0x47, 0xd1, 0xd6, 0xf6, 0xdf,
		0x9a, 0xec, 0x6e, 0x8b, 0xd0, 0x4b, 0x56, 0x27, 0x50, 0xe1, 0x7d, 0xa0,
		0x7b, 0xd9, 0xf4, 0x61, 0x09, 0x93, 0x99, 0xc9, 0x30, 0x06, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0xf7,
		0x04, 0x27, 0x23, 0xcb, 0xd0, 0x71, 0x39, 0xaf, 0xa7, 0xcb, 0x47, 0x8f,
		0x2e, 0xea, 0x53, 0x61, 0xa9, 0xb9, 0xaa, 0x37, 0xd3, 0xe5, 0x62, 0x0f,
		0xea, 0x5c, 0xbd, 0x56, 0x4c, 0xdd, 0xd3, 0xfa, 0xce, 0x55, 0xbd, 0x6e,
		0xd6, 0xee, 0xbb, 0xab, 0xb7, 0xb8, 0x0a, 0x9d, 0x43, 0x4a, 0x29, 0xf5,
		0x54, 0x40, 0x5d, 0x2c, 0x5e, 0x39, 0xd4, 0x50, 0x67, 0x61, 0x66, 0x7f,
		0xa1, 0x0f, 0x75, 0x94, 0x68, 0xad, 0x5b, 0xab, 0x9c, 0x5e, 0x1d, 0xdc,
		0xdb, 0x14, 0x20, 0xfb, 0xbd, 0x98, 0x5a, 0x1d, 0x3d, 0x64, 0xc9, 0x42,
		0xc8, 0x2b, 0x62, 0x35, 0xdf, 0x16, 0x63, 0x6a, 0x31, 0xad, 0xba, 0xf4,
		0xee, 0x4b, 0xcd, 0xeb, 0xd6, 0xd9, 0x6e, 0xb7, 0x07, 0xf4, 0x5f, 0x7d,
		0x23, 0x44, 0xb5, 0x19, 0xb3, 0x20, 0xd9, 0x1d, 0x10, 0xab, 0x23, 0x93,
		0x92, 0xbb, 0x59, 0x5c, 0x27, 0x2f, 0xb4, 0xea, 0xa5, 0x53, 0x51, 0x1d,
		0x1b, 0x03, 0x46, 0xad, 0x5e, 0xf0, 0x74, 0xd0, 0x97, 0x85, 0xa8, 0x84,
		0xff, 0x51, 0xed, 0x6b, 0x43, 0xcc, 0x5e, 0xd7, 0x56, 0xfc, 0xa8, 0x03,
		0x73, 0x18, 0x3f, 0x3d, 0xe5, 0x6b, 0xf3, 0x6f, 0x79, 0x1b, 0x2b, 0x1f,
		0xea, 0x0d, 0x9b, 0xf3, 0x8e, 0x5b, 0x71, 0x48, 0xaf, 0x2e, 0xa7, 0xfd,
		0x9a, 0x1c, 0xde, 0xb2, 0x90, 0xbc, 0x14, 0xe4, 0xe9, 0x5a, 0x1e, 0xc5,
		0xe4, 0xea, 0xa5, 0xc3, 0x3c, 0xa7, 0x7e, 0x91, 0x57, 0x19, 0x9e, 0xe4,
		0x6e, 0xd9, 0xa5, 0x2f, 0xbb, 0x41, 0x67, 0x90, 0xba, 0xab, 0x31, 0xb9,
		0x9a, 0xb1, 0xe4, 0x3e, 0x95, 0x5f, 0x7b, 0x50, 0x2b, 0x96, 0xbc, 0x1a,
		0xf5, 0x59, 0xe8, 0xa3, 0x7b, 0xe2, 0xb6, 0x46, 0x2e, 0xf8, 0x69, 0xcc,
		0xf8, 0x8e, 0xd9, 0x6c, 0x4f, 0x3d, 0xdf, 0xdc, 0xf4, 0x3d, 0x87, 0x4a,
		0x5d, 0x9e, 0x2e, 0xe9, 0xb3, 0xab, 0x9e, 0x04, 0xc5, 0x3c, 0xf5, 0x86,
		0x94, 0x1a, 0x3f, 0x52, 0xe0, 0x22, 0xa9, 0xba, 0x7e, 0xd5, 0xcc, 0x9a,
		0xdf, 0xc8, 0x68, 0x2a, 0xb4, 0x6a, 0x71, 0x7e, 0x67, 0x77, 0x38, 0xb0,
		0x5d, 0xe5, 0x07, 0xe5, 0x91, 0xb1, 0x2d, 0x9f, 0x1c, 0xea, 0x96, 0x7e,
		0x33, 0x6f, 0x65, 0x83, 0xf8, 0xab, 0x2d, 0x17, 0xe9, 0xf3, 0x92, 0x34,
		0xf3, 0xf1, 0xfa, 0xa4, 0x05, 0x16, 0xf2, 0x9a, 0x36, 0xa9, 0x96, 0x07,
		0x13, 0xf3, 0x01, 0x75, 0x95, 0x49, 0x5e, 0xf2, 0x61, 0xc6, 0x33, 0x79,
		0xd9, 0xe5, 0x41, 0xd2, 0x39, 0x19, 0xf5, 0x7b, 0x4d, 0xee, 0xe1, 0x72,
		0xa7, 0x7e, 0x3c, 0xff, 0xa0, 0x56, 0x4a, 0x39, 0x5f, 0x75, 0x8b, 0xcd,
		0x43, 0x0a, 0x4e, 0x71, 0xf4, 0x3e, 0x26, 0x66, 0xb3, 0xa6, 0x66, 0x3a,
		0xc3, 0x35, 0x42, 0xd6, 0xd3, 0xd5, 0x9d, 0x86, 0xe3, 0x70, 0x4d, 0x15,
		0x0c, 0x3e, 0x83, 0xfb, 0xf0, 0x0e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 0xf2, 0x0d, 0xcb, 0x59, 0xb8,
		0xf2, 0x40, 0x72, 0x52, 0xc5, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58,
		0x74, 0x52, 0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65,
		0x20, 0x74, 0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00,
		0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f,
		0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b,
		0x13, 0x23, 0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34,
		0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4,
		0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00,
		0xea, 0x17, 0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00,
		0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func appleTouchIconPrecomposedPng(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0xb4, 0x00, 0x00, 0x00, 0xb4,
		0x08, 0x03, 0x00, 0x00, 0x00, 0x0a, 0x13, 0xf6, 0x00, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x09, 0x70, 0x48, 0x59, 0x73, 0x00, 0x00,
		0x0b, 0x13, 0x00, 0x00, 0x0b, 0x13, 0x01, 0x00, 0x9a, 0x9c, 0x18, 0x00,
		0x00, 0x00, 0x33, 0x50, 0x4c, 0x54, 0x45, 0x4c, 0x69, 0x71, 0x22, 0x2b,
		0x2e, 0xdb, 0xeb, 0xef, 0xdf, 0xef, 0xf4, 0x22, 0x2b, 0x2e, 0x22, 0x2b,
		0x2e, 0x22, 0x2b, 0x2e, 0x2b, 0x34, 0x37, 0x22, 0x2b, 0x2e, 0x22, 0x2b,
		0x2e, 0x1e, 0x27, 0x2a, 0xa6, 0xb3, 0xb8, 0xc7, 0xd6, 0xdb, 0x5f, 0x6a,
		0x6d, 0x3a, 0x44, 0x47, 0x8a, 0x96, 0x9a, 0x75, 0x81, 0x85, 0xfb, 0xa2,
		0xd1, 0x47, 0x00, 0x00, 0x00, 0x0a, 0x74, 0x52, 0x4e, 0x53, 0x00, 0xff,
		0xff, 0xff, 0xde, 0x66, 0xc9, 0xfe, 0xa7, 0x24, 0xd9, 0x8e, 0x96, 0xee,
		0x00, 0x00, 0x03, 0x3d, 0x49, 0x44, 0x41, 0x54, 0x78, 0xda, 0xed, 0x9d,
		0xdb, 0x72, 0xa3, 0x30, 0x10, 0x44, 0x2d, 0x2e, 0x35, 0xa0, 0xfb, 0xff,
		0x7f, 0xed, 0x0a, 0x90, 0x6d, 0x88, 0xb3, 0x31, 0xde, 0x85, 0x65, 0x7a,
		0xab, 0xe7, 0x25, 0x79, 0x48, 0x94, 0x93, 0xae, 0x61, 0xd4, 0x1a, 0x54,
		0x9e, 0xdb, 0xed, 0x35, 0xc6, 0x7e, 0xe8, 0xc4, 0x28, 0x08, 0xe9, 0x86,
		0x7e, 0xbc, 0xbd, 0x8f, 0xb1, 0xef, 0x8c, 0xb2, 0xe8, 0xde, 0x80, 0x8f,
		0x83, 0x51, 0x19, 0xc3, 0x08, 0x87, 0xfc, 0x13, 0x76, 0x6f, 0x54, 0x47,
		0xff, 0x1d, 0xf3, 0x60, 0x94, 0xc7, 0xf0, 0xca, 0xdc, 0x19, 0xf5, 0xd1,
		0x01, 0x32, 0xbf, 0x50, 0x43, 0x30, 0x7f, 0xa1, 0x1e, 0x0c, 0x48, 0x0c,
		0x30, 0x75, 0xe3, 0xdb, 0x1a, 0x32, 0x1a, 0xa0, 0x18, 0xd1, 0x92, 0x63,
		0x95, 0x20, 0x50, 0x42, 0xdf, 0xa5, 0x1e, 0xb0, 0xa0, 0x07, 0x40, 0xa1,
		0x17, 0xa9, 0x7b, 0x34, 0xe8, 0x1e, 0x67, 0x5f, 0xd9, 0xee, 0x30, 0x06,
		0x2e, 0x00, 0x53, 0x7a, 0x4a, 0xea, 0x1e, 0x0f, 0xba, 0x47, 0x2b, 0x78,
		0x4b, 0xd1, 0xeb, 0xf0, 0xa0, 0xbb, 0x9b, 0xe0, 0x41, 0x0b, 0x60, 0xf1,
		0x28, 0xe5, 0x83, 0xd0, 0x84, 0x26, 0x34, 0xa1, 0x09, 0x4d, 0x68, 0x42,
		0x13, 0x9a, 0xd0, 0x84, 0x26, 0x34, 0xa1, 0x09, 0x4d, 0x68, 0x42, 0x13,
		0x9a, 0xd0, 0x84, 0x26, 0x34, 0xa1, 0x09, 0x4d, 0x68, 0x42, 0x13, 0x1a,
		0x0f, 0x5a, 0xdc, 0x3a, 0xd2, 0xc1, 0x04, 0x36, 0x7e, 0xbc, 0xfc, 0x1e,
		0xe8, 0xe8, 0xdb, 0x55, 0x78, 0x39, 0x1a, 0xba, 0x59, 0x2f, 0xef, 0x0e,
		0x83, 0x6e, 0x9e, 0x71, 0x06, 0xf4, 0x7a, 0xf9, 0x83, 0xa0, 0x2d, 0x22,
		0xf4, 0x56, 0xe9, 0xc6, 0x41, 0x29, 0x9d, 0xc2, 0x12, 0x47, 0xd7, 0x02,
		0xa9, 0xeb, 0xba, 0xf6, 0x04, 0xa5, 0x83, 0x3d, 0xb5, 0x8e, 0xd9, 0xd4,
		0x9e, 0xa0, 0x34, 0x14, 0x34, 0x95, 0xa6, 0xd2, 0x54, 0x1a, 0x56, 0x69,
		0x6b, 0xef, 0x5f, 0x2d, 0x8a, 0xd2, 0x56, 0x62, 0xc8, 0x53, 0x84, 0x10,
		0xa3, 0x18, 0x8b, 0xa0, 0x74, 0xcc, 0xee, 0xb1, 0xf5, 0x7b, 0xef, 0x52,
		0x8e, 0xda, 0x95, 0xb6, 0x31, 0xfb, 0xa6, 0x5d, 0xfb, 0x89, 0xb6, 0xf1,
		0x49, 0x74, 0x2b, 0x1d, 0x5d, 0xf3, 0x12, 0x3b, 0xbc, 0xe1, 0xa5, 0x4a,
		0x3f, 0x98, 0xab, 0xab, 0xaf, 0x49, 0xa2, 0x5a, 0x69, 0xb9, 0x33, 0xfb,
		0x72, 0x74, 0x9a, 0xce, 0x4f, 0x1e, 0x40, 0xe9, 0x5c, 0x5d, 0x77, 0x88,
		0x13, 0xa6, 0x48, 0x8c, 0x21, 0x15, 0x70, 0xd5, 0x4a, 0xcb, 0xec, 0x8a,
		0x9b, 0x24, 0xeb, 0x3a, 0x2d, 0x85, 0x5b, 0xb1, 0xd2, 0xf5, 0x1f, 0x7c,
		0x45, 0x8c, 0x8a, 0x95, 0xb6, 0x61, 0xfe, 0xd1, 0x0c, 0xe5, 0x3d, 0x2a,
		0xf4, 0x9f, 0xd8, 0x94, 0x0b, 0x95, 0xce, 0x4a, 0xa0, 0x0d, 0x62, 0x7a,
		0x7c, 0x96, 0xd3, 0x7e, 0xfe, 0xcb, 0xd1, 0x02, 0x29, 0x5d, 0xf6, 0xc3,
		0x76, 0x29, 0xd3, 0x50, 0x7e, 0x3a, 0xd5, 0xfd, 0x30, 0x4f, 0x8e, 0xd4,
		0x62, 0x28, 0xfd, 0x6c, 0x47, 0x15, 0x47, 0x5a, 0xbc, 0xb4, 0xb1, 0x08,
		0x4a, 0x4b, 0x58, 0x35, 0xd1, 0x66, 0x2b, 0xbd, 0xef, 0x0c, 0x70, 0xb1,
		0x9f, 0x5e, 0x53, 0xb7, 0x13, 0x78, 0x88, 0xda, 0x95, 0x2e, 0x5a, 0x47,
		0xe7, 0xb7, 0x6e, 0xda, 0x65, 0xd1, 0xae, 0xf4, 0x94, 0x22, 0x6e, 0x73,
		0x76, 0x69, 0x9b, 0x14, 0x95, 0x2b, 0x5d, 0x4f, 0x89, 0x69, 0xa3, 0xb7,
		0x13, 0xed, 0x4a, 0xcf, 0x0c, 0x26, 0x16, 0xf0, 0x27, 0x77, 0x06, 0x50,
		0x7a, 0xe9, 0x7c, 0x48, 0x39, 0x01, 0x54, 0x6e, 0xff, 0x6e, 0x93, 0x54,
		0xd4, 0x61, 0xb2, 0x25, 0xbf, 0xf7, 0x49, 0xad, 0xaa, 0x97, 0x67, 0x6b,
		0x09, 0x7c, 0x97, 0xd5, 0xba, 0x7a, 0x79, 0x92, 0x2e, 0x80, 0xfe, 0xeb,
		0xae, 0x69, 0xde, 0xd5, 0x44, 0x50, 0xd6, 0x35, 0xbd, 0x02, 0xfa, 0x33,
		0xa5, 0xed, 0xef, 0x8c, 0x9f, 0xde, 0x9c, 0x96, 0x6f, 0x7c, 0xc6, 0xfd,
		0x8d, 0x9e, 0xda, 0xea, 0x21, 0xce, 0xa7, 0xb0, 0xb1, 0x75, 0xb6, 0x3e,
		0x87, 0x4d, 0x30, 0x6a, 0x95, 0x2e, 0x07, 0x17, 0xef, 0x72, 0x90, 0x95,
		0x0d, 0xa9, 0xfb, 0xf8, 0xbf, 0xdd, 0x5c, 0x3e, 0x53, 0xfa, 0xe1, 0xa3,
		0xa7, 0x97, 0xb0, 0x0f, 0x03, 0xd2, 0xfa, 0xb7, 0xe7, 0xaf, 0x2b, 0x95,
		0x7e, 0xf8, 0xe8, 0xed, 0x37, 0x59, 0x71, 0x87, 0xa9, 0xb6, 0xf2, 0xbe,
		0x86, 0xdf, 0x61, 0xa8, 0x2f, 0x54, 0x3a, 0x7b, 0xff, 0x8a, 0xbc, 0xeb,
		0x6c, 0x7e, 0x65, 0x9d, 0x5e, 0x3a, 0xbb, 0x6b, 0xe4, 0x14, 0x76, 0x5d,
		0xb6, 0xb8, 0x74, 0x47, 0x9c, 0x0d, 0x69, 0x4e, 0xf5, 0x46, 0x52, 0x0e,
		0x51, 0x76, 0xfe, 0xde, 0xc5, 0xde, 0x63, 0xee, 0x77, 0x48, 0x09, 0x63,
		0xf6, 0xf7, 0x3e, 0xce, 0x52, 0x7a, 0x09, 0x73, 0x74, 0xd4, 0x75, 0x4f,
		0x51, 0x3a, 0xe5, 0xe5, 0x75, 0xe6, 0xd1, 0xcc, 0xb2, 0xac, 0x9b, 0x4f,
		0xb9, 0x59, 0xd3, 0x9c, 0x7c, 0xc5, 0x8d, 0xb7, 0xc5, 0x50, 0xef, 0xe5,
		0x01, 0xde, 0x80, 0xbc, 0x3f, 0x29, 0x35, 0x8e, 0x7e, 0x10, 0xe3, 0x66,
		0xf5, 0x70, 0x10, 0xf4, 0xbd, 0x26, 0x9d, 0x54, 0xf2, 0xec, 0xc7, 0xcb,
		0xf3, 0xfe, 0x34, 0xa1, 0x09, 0x4d, 0x68, 0x42, 0x13, 0x9a, 0xd0, 0x84,
		0x26, 0x34, 0xa1, 0x09, 0x4d, 0x68, 0x42, 0x13, 0x9a, 0xd0, 0x84, 0x26,
		0x34, 0xa1, 0x09, 0x4d, 0x68, 0x42, 0x13, 0x9a, 0xd0, 0xff, 0x35, 0x34,
		0xe4, 0x07, 0xc1, 0x43, 0x7e, 0xe4, 0x3e, 0xe4, 0x70, 0x03, 0xc8, 0x31,
		0x12, 0x90, 0x03, 0x3b, 0x20, 0x47, 0xa3, 0x60, 0x0e, 0xa1, 0x81, 0x1c,
		0xf7, 0x03, 0x39, 0x58, 0x09, 0x72, 0x84, 0x15, 0xe6, 0xb0, 0x30, 0xc8,
		0xb1, 0x6c, 0x98, 0x03, 0xf0, 0x20, 0x47, 0x0d, 0x62, 0x0e, 0x75, 0xc4,
		0x1c, 0x9f, 0x89, 0x39, 0xa8, 0x14, 0x73, 0x24, 0x2c, 0xe6, 0xf0, 0x5d,
		0xcc, 0x31, 0xc7, 0x98, 0x03, 0xa5, 0x31, 0x47, 0x77, 0x83, 0x0e, 0x49,
		0x07, 0x19, 0x47, 0xff, 0x0b, 0x90, 0x21, 0xa9, 0xbb, 0xa4, 0x3a, 0x0f,
		0x28, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52, 0x61, 0x77,
		0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74, 0x79, 0x70,
		0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c, 0xe3, 0xf2,
		0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc, 0x49, 0xe5,
		0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23, 0x13, 0x4b,
		0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64, 0x03, 0x23,
		0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4, 0x1c, 0xc4,
		0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17, 0x11, 0x74,
		0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44,
		0xae, 0x42, 0x60, 0x82,
	})
}

func mstile144x144Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x90, 0x00, 0x00, 0x00, 0x90,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x15, 0x68, 0xff, 0x8b, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x18, 0x50, 0x4c, 0x54, 0x45, 0x4c, 0x69,
		0x71, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0xda, 0xe8,
		0xec, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0x25, 0xc7,
		0x22, 0x80, 0x00, 0x00, 0x00, 0x08, 0x74, 0x52, 0x4e, 0x53, 0x00, 0xfe,
		0xbf, 0x3c, 0x10, 0x5c, 0xdb, 0x88, 0xb8, 0xfb, 0x70, 0x8f, 0x00, 0x00,
		0x01, 0x4d, 0x49, 0x44, 0x41, 0x54, 0x68, 0xde, 0xed, 0x97, 0x4d, 0x6b,
		0x83, 0x40, 0x10, 0x86, 0x05, 0x15, 0xcf, 0x63, 0x61, 0xcf, 0xd5, 0x83,
		0x5e, 0x4d, 0x4c, 0xe3, 0x55, 0xea, 0xe6, 0xde, 0xc4, 0x48, 0xcf, 0x5a,
		0x9a, 0x5e, 0x2b, 0x69, 0xf0, 0xef, 0x77, 0x4d, 0x24, 0x07, 0x0f, 0x5d,
		0x71, 0x96, 0x60, 0xe1, 0x7d, 0xce, 0xc3, 0x83, 0x8c, 0xf3, 0xb1, 0x63,
		0x59, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfe, 0x01, 0xeb,
		0x50, 0x11, 0xe7, 0x93, 0xa2, 0xfe, 0x0c, 0x59, 0x91, 0x42, 0xe8, 0x44,
		0xfb, 0x3e, 0xca, 0x7f, 0xa0, 0xc8, 0x37, 0x22, 0x12, 0x55, 0x55, 0xea,
		0x32, 0xb9, 0xab, 0xaa, 0x56, 0x2b, 0xd2, 0x7e, 0xce, 0x3d, 0x10, 0xa2,
		0x45, 0x8b, 0x0a, 0x55, 0x11, 0x1b, 0xbe, 0xc8, 0xc9, 0x6a, 0x55, 0x7e,
		0xcd, 0x25, 0xe1, 0x8a, 0xd6, 0x74, 0xe3, 0x83, 0x29, 0xb2, 0xeb, 0x41,
		0xf4, 0xc4, 0x14, 0xbd, 0xaa, 0x26, 0x0e, 0xc3, 0x88, 0x2f, 0x6a, 0x49,
		0x94, 0xb9, 0x25, 0x5f, 0x22, 0xa6, 0xc8, 0xa9, 0x87, 0xe4, 0xd8, 0x47,
		0x9e, 0x48, 0xa5, 0xe8, 0xcd, 0x48, 0x1d, 0xb9, 0x44, 0xc9, 0xb2, 0x44,
		0x36, 0xd1, 0xb7, 0x19, 0x51, 0x4d, 0x9f, 0x66, 0x7a, 0x2d, 0x20, 0x3a,
		0xe7, 0x26, 0x44, 0x5b, 0x55, 0x90, 0x71, 0x99, 0xf3, 0x45, 0x6e, 0xdf,
		0x22, 0x22, 0x3e, 0xf2, 0xbb, 0xff, 0x70, 0xed, 0x34, 0xff, 0x87, 0x3f,
		0x46, 0x06, 0x13, 0x7b, 0x8c, 0xa8, 0x81, 0x14, 0x99, 0x18, 0x23, 0x3d,
		0x32, 0x0b, 0xc6, 0xfb, 0x77, 0xee, 0xcc, 0xde, 0x05, 0xa3, 0x0a, 0x9f,
		0x3d, 0xfc, 0xb7, 0xa3, 0x0a, 0x9f, 0x2d, 0xf2, 0x88, 0x9e, 0x8d, 0x88,
		0xdc, 0xc5, 0x88, 0xec, 0xe4, 0x3e, 0xba, 0x79, 0x39, 0xf2, 0xbe, 0xae,
		0xab, 0xd1, 0xd9, 0x73, 0xff, 0x9a, 0x47, 0xcd, 0x59, 0xca, 0xe2, 0xc0,
		0xae, 0x23, 0xaf, 0xdf, 0xb2, 0xe1, 0x89, 0x5f, 0xd9, 0xde, 0xb0, 0x1e,
		0xd9, 0xbd, 0xe6, 0x46, 0x37, 0x8f, 0x60, 0x77, 0x7f, 0xf1, 0x1e, 0xd5,
		0x24, 0x9a, 0xd2, 0xc0, 0xb3, 0x46, 0xa6, 0x69, 0x6a, 0x60, 0x42, 0xce,
		0x7e, 0x68, 0x89, 0xae, 0xbb, 0xe8, 0x2c, 0x59, 0xd7, 0xb5, 0x0f, 0x3d,
		0x21, 0x16, 0x25, 0x52, 0x57, 0x86, 0x62, 0xc2, 0x2d, 0x32, 0xe1, 0x62,
		0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xc0, 0xe0, 0x17, 0xdc,
		0xbb, 0x59, 0xd4, 0xb3, 0x5c, 0x4b, 0x04, 0x00, 0x00, 0x00, 0x57, 0x7a,
		0x54, 0x58, 0x74, 0x52, 0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69,
		0x6c, 0x65, 0x20, 0x74, 0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63,
		0x00, 0x00, 0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28,
		0xca, 0x4f, 0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e,
		0x63, 0x0b, 0x13, 0x23, 0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44,
		0x80, 0x34, 0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4,
		0xc8, 0xc4, 0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a,
		0x2e, 0x00, 0xea, 0x17, 0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00,
		0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func mstile150x150Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x01, 0x0e, 0x00, 0x00, 0x01, 0x0e,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x8a, 0x9f, 0xe4, 0x96, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x15, 0x50, 0x4c, 0x54, 0x45, 0x4c, 0x69,
		0x71, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0xda, 0xea, 0xee, 0xdb, 0xeb,
		0xef, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0x6c, 0xf5, 0xe6, 0x02, 0x00,
		0x00, 0x00, 0x07, 0x74, 0x52, 0x4e, 0x53, 0x00, 0xfd, 0xc4, 0x09, 0x54,
		0x28, 0x97, 0xc5, 0x76, 0xcf, 0x2f, 0x00, 0x00, 0x01, 0x6c, 0x49, 0x44,
		0x41, 0x54, 0x78, 0xda, 0xed, 0xd8, 0x4d, 0x4f, 0xdb, 0x40, 0x10, 0x06,
		0xe0, 0x48, 0x8e, 0xb9, 0xaf, 0x55, 0x71, 0x77, 0x68, 0x38, 0x5b, 0x0d,
		0xe1, 0x0c, 0xe5, 0xe3, 0x4c, 0x49, 0xd2, 0x7b, 0x43, 0xca, 0xff, 0xff,
		0x09, 0x5d, 0x1b, 0x71, 0xb0, 0x54, 0x39, 0x1c, 0x80, 0x59, 0x89, 0xe7,
		0x39, 0x46, 0x23, 0xf9, 0x55, 0x32, 0x9e, 0xd9, 0xcd, 0x6c, 0x06, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xf0, 0x46,
		0xd5, 0x2a, 0xeb, 0xa6, 0x2a, 0x8e, 0x16, 0xbc, 0x8b, 0xcb, 0x45, 0xf6,
		0x34, 0x51, 0x30, 0xef, 0x0b, 0x96, 0x1f, 0x9e, 0xe3, 0x47, 0xca, 0xce,
		0xa6, 0x72, 0xf4, 0x05, 0xdf, 0xbe, 0x50, 0x8e, 0xe6, 0xe8, 0xef, 0xd2,
		0x7e, 0x4a, 0x8e, 0xd3, 0xa3, 0x7d, 0xfa, 0xeb, 0x73, 0x72, 0x1c, 0xad,
		0x91, 0x43, 0x8e, 0xd1, 0x88, 0xed, 0x0a, 0xc8, 0x51, 0x6d, 0xf7, 0x8b,
		0xf3, 0xc3, 0x26, 0x3c, 0xc7, 0xef, 0x7e, 0x6e, 0xa5, 0xe6, 0x2a, 0x38,
		0xc7, 0xbc, 0x1d, 0x72, 0x8c, 0x46, 0x6c, 0x44, 0x8e, 0xc7, 0x94, 0xf2,
		0x5e, 0x8b, 0xcf, 0xf1, 0x27, 0x7d, 0xdf, 0xac, 0xd6, 0xdb, 0x7d, 0x70,
		0x8e, 0xba, 0x4d, 0x43, 0x67, 0xd4, 0xc1, 0xfd, 0x51, 0xa7, 0xa6, 0x2b,
		0x61, 0x7e, 0xcc, 0xff, 0x37, 0xd6, 0x42, 0x72, 0x94, 0xf1, 0x7d, 0xd4,
		0x29, 0xdd, 0x94, 0x90, 0xa3, 0x6a, 0xd3, 0xe9, 0xa6, 0x84, 0xfd, 0x72,
		0x9d, 0x67, 0xe9, 0x61, 0x13, 0x9f, 0x63, 0x38, 0x8e, 0x36, 0x87, 0x2e,
		0x7c, 0xbf, 0xfc, 0x1c, 0xc6, 0xfa, 0x32, 0x7e, 0xdf, 0xde, 0x0f, 0x1b,
		0x26, 0x7a, 0xcf, 0x65, 0xeb, 0x3e, 0xc9, 0xb2, 0x80, 0xf3, 0x58, 0xb5,
		0x6d, 0x47, 0x9f, 0xc6, 0x9d, 0x0b, 0x1f, 0x53, 0xf3, 0x50, 0x42, 0x8e,
		0xfc, 0xd6, 0xc8, 0x31, 0xb4, 0x46, 0x21, 0x39, 0xe6, 0x7f, 0x5f, 0xfb,
		0xa3, 0x0b, 0xcd, 0x71, 0x92, 0x87, 0x7a, 0x57, 0x5d, 0x8c, 0x6f, 0xd6,
		0x11, 0x39, 0xf2, 0xf1, 0xf4, 0xf9, 0xb9, 0x0d, 0x3f, 0x9f, 0x9e, 0xbc,
		0x9c, 0xd6, 0x47, 0xaf, 0x6d, 0x48, 0x7f, 0xec, 0x5f, 0x62, 0xdc, 0x44,
		0xef, 0x97, 0xf5, 0xfd, 0x7e, 0xb1, 0x38, 0xbf, 0x2b, 0xe0, 0x7e, 0xbb,
		0x5a, 0x07, 0xdd, 0x6f, 0x77, 0xbb, 0x87, 0x89, 0x82, 0x6a, 0xb7, 0xbb,
		0xfe, 0x52, 0xff, 0xd3, 0xc9, 0x31, 0x7a, 0xcc, 0x6d, 0x76, 0x35, 0x51,
		0x50, 0xf7, 0x05, 0x77, 0x33, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xe0, 0xc3,
		0xfc, 0x03, 0xe5, 0x62, 0x45, 0x1b, 0xd5, 0x93, 0x49, 0xee, 0x00, 0x00,
		0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52, 0x61, 0x77, 0x20, 0x70, 0x72,
		0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74, 0x79, 0x70, 0x65, 0x20, 0x69,
		0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71,
		0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03,
		0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23, 0x13, 0x4b, 0x93, 0x14, 0x03,
		0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54, 0x20,
		0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80,
		0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17, 0x11, 0x74, 0xf2, 0x42, 0x35,
		0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42, 0x60,
		0x82,
	})
}

func mstile310x150Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x02, 0x2e, 0x00, 0x00, 0x01, 0x0e,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x5c, 0x20, 0x81, 0x47, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x0f, 0x50, 0x4c, 0x54, 0x45, 0x4c, 0x69,
		0x71, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0xdb, 0xeb,
		0xef, 0x72, 0x38, 0x77, 0xff, 0x00, 0x00, 0x00, 0x05, 0x74, 0x52, 0x4e,
		0x53, 0x00, 0xfd, 0x3f, 0xc4, 0x8f, 0x4b, 0xc1, 0xe6, 0x9d, 0x00, 0x00,
		0x01, 0x7a, 0x49, 0x44, 0x41, 0x54, 0x78, 0xda, 0xed, 0xda, 0x41, 0x72,
		0x82, 0x30, 0x18, 0x80, 0x51, 0xc6, 0x7a, 0x81, 0x14, 0x0e, 0x10, 0xa3,
		0x07, 0x28, 0xc2, 0x01, 0xac, 0x78, 0xff, 0x33, 0x15, 0xa8, 0xd3, 0x1a,
		0xa0, 0xd8, 0xce, 0x74, 0xba, 0xa8, 0xef, 0x2d, 0x9d, 0x6c, 0xfc, 0x06,
		0xc2, 0x1f, 0xb1, 0x28, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x7e, 0xd9, 0xb6, 0xe9, 0x9d, 0x56, 0x16,
		0x6c, 0x86, 0x05, 0xc7, 0x87, 0xeb, 0xf2, 0x14, 0x7a, 0x2f, 0x6b, 0xe1,
		0x86, 0x05, 0xcf, 0xba, 0xe8, 0x72, 0xed, 0x52, 0xde, 0xbd, 0x8f, 0xea,
		0x87, 0xec, 0x52, 0xdd, 0x5d, 0xb3, 0xd3, 0x45, 0x17, 0x5d, 0x74, 0xd1,
		0x45, 0x97, 0x3f, 0xef, 0x72, 0xe8, 0x9a, 0xf6, 0x12, 0x75, 0x99, 0x74,
		0x39, 0x0c, 0x73, 0x5c, 0x28, 0x4f, 0xba, 0xe4, 0x63, 0x5c, 0x3d, 0x76,
		0xc9, 0x46, 0x60, 0x5d, 0x8a, 0x62, 0x1f, 0x42, 0x7f, 0x4e, 0xd4, 0x65,
		0xda, 0xe5, 0x35, 0xb4, 0xfd, 0xde, 0x92, 0x3a, 0x5d, 0xaa, 0xc9, 0x6d,
		0x34, 0x6e, 0xb9, 0x9b, 0xa8, 0x4b, 0xd6, 0x25, 0x94, 0x9e, 0xd3, 0x8b,
		0x5d, 0x2a, 0x5d, 0x5c, 0x2f, 0x3f, 0xe8, 0x12, 0x4e, 0xba, 0x2c, 0x3c,
		0x8f, 0xea, 0x50, 0x45, 0x5d, 0xe6, 0x5d, 0x76, 0xfd, 0xac, 0x7b, 0x8e,
		0xba, 0x4c, 0xbb, 0x8c, 0x3f, 0xe7, 0x96, 0x67, 0x5d, 0xa6, 0x0f, 0xa0,
		0xfd, 0x78, 0x0c, 0x38, 0xea, 0x32, 0x3b, 0x4f, 0x8f, 0x27, 0x24, 0x73,
		0xdd, 0x6c, 0x60, 0xd9, 0x5c, 0xea, 0xfc, 0x82, 0xd1, 0xe5, 0xf3, 0x34,
		0x50, 0xe9, 0xb2, 0xf0, 0xe9, 0x3e, 0x1b, 0xef, 0x74, 0xb9, 0x79, 0x2a,
		0x45, 0x5d, 0x16, 0x6e, 0x24, 0x5d, 0x5c, 0x2f, 0xdf, 0x3a, 0x1f, 0x9d,
		0xaf, 0x9f, 0xda, 0x5f, 0xb2, 0x2e, 0xdb, 0xf1, 0x10, 0xe0, 0x79, 0x34,
		0xeb, 0x12, 0x42, 0x73, 0xe9, 0x6a, 0xbf, 0xef, 0xce, 0xbb, 0xbc, 0xbf,
		0x27, 0x31, 0xef, 0xe6, 0xfb, 0x4b, 0x37, 0x7f, 0x7d, 0xa4, 0xcb, 0x10,
		0xe6, 0xd0, 0x35, 0x4d, 0x1b, 0x9d, 0xa7, 0xbd, 0x9f, 0xfe, 0xaa, 0x4b,
		0x4a, 0x71, 0x6d, 0x45, 0x4a, 0x3b, 0xff, 0x3b, 0x5c, 0x1c, 0x7d, 0xfd,
		0x1f, 0x73, 0x79, 0xf4, 0xd5, 0xc5, 0xf5, 0xf2, 0xf1, 0xb5, 0x53, 0x5a,
		0xdf, 0x5f, 0xee, 0x2e, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x80, 0x7f, 0xef, 0x0d, 0x3d, 0xae, 0x29, 0xbf,
		0x47, 0x91, 0x56, 0x6b, 0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74,
		0x52, 0x61, 0x77, 0x20, 0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20,
		0x74, 0x79, 0x70, 0x65, 0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78,
		0x9c, 0xe3, 0xf2, 0x0c, 0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb,
		0xcc, 0x49, 0xe5, 0x52, 0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13,
		0x23, 0x13, 0x4b, 0x93, 0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3,
		0x64, 0x03, 0x23, 0xb3, 0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc,
		0xc4, 0x1c, 0xc4, 0x07, 0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea,
		0x17, 0x11, 0x74, 0xf2, 0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49,
		0x45, 0x4e, 0x44, 0xae, 0x42, 0x60, 0x82,
	})
}

func mstile310x310Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x02, 0x2e, 0x00, 0x00, 0x02, 0x2e,
		0x02, 0x03, 0x00, 0x00, 0x00, 0xe5, 0x24, 0x6b, 0x4c, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x0c, 0x50, 0x4c, 0x54, 0x45, 0x4c, 0x69,
		0x71, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0x2a, 0x90,
		0xff, 0x82, 0x00, 0x00, 0x00, 0x03, 0x74, 0x52, 0x4e, 0x53, 0x00, 0x44,
		0xbc, 0xac, 0xb4, 0xb1, 0x78, 0x00, 0x00, 0x02, 0x22, 0x49, 0x44, 0x41,
		0x54, 0x78, 0xda, 0xed, 0xda, 0x3d, 0x72, 0xd3, 0x50, 0x14, 0x80, 0x51,
		0x29, 0x83, 0x4d, 0x41, 0x43, 0xe3, 0x26, 0x14, 0xf4, 0x34, 0xd9, 0x82,
		0x96, 0xe0, 0x02, 0x51, 0x40, 0x4b, 0x15, 0x0a, 0x96, 0x10, 0x96, 0xe0,
		0x22, 0xec, 0x80, 0x14, 0x16, 0x45, 0x96, 0xa0, 0x2d, 0xb0, 0x04, 0x8a,
		0x50, 0x24, 0x35, 0x4d, 0x5c, 0xe8, 0xf1, 0xa4, 0xd8, 0x85, 0x81, 0xb1,
		0xc9, 0x90, 0xb1, 0x2e, 0xc3, 0x39, 0xb5, 0x66, 0xf4, 0x4d, 0xa2, 0x9f,
		0x77, 0x9f, 0x55, 0x14, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc, 0x91, 0x59,
		0x9d, 0x55, 0x7f, 0x77, 0xc4, 0x83, 0x39, 0x4b, 0xd9, 0x87, 0x5d, 0x47,
		0x9c, 0xf4, 0x47, 0x7c, 0x11, 0x23, 0x46, 0xcc, 0xfe, 0x98, 0x55, 0xd3,
		0xec, 0x8c, 0x79, 0xd1, 0x34, 0x87, 0x8b, 0xf9, 0xb6, 0xff, 0x39, 0xd3,
		0x1e, 0x2c, 0xe6, 0xeb, 0xfe, 0x83, 0xc4, 0x88, 0x11, 0x23, 0x46, 0xcc,
		0xff, 0x18, 0xf3, 0x28, 0x4e, 0x4c, 0xf9, 0xaa, 0x59, 0xd6, 0x51, 0x62,
		0x5e, 0xe7, 0xe5, 0xcb, 0xea, 0x63, 0x8c, 0x98, 0x49, 0xdb, 0x2f, 0xa6,
		0xba, 0xf3, 0x10, 0x31, 0xcf, 0xd2, 0xe0, 0x7b, 0x84, 0x98, 0xf2, 0x7d,
		0xa0, 0x98, 0xa3, 0x14, 0x28, 0xe6, 0x71, 0xa4, 0x98, 0x7c, 0xc9, 0xdc,
		0x34, 0x4d, 0x1b, 0x23, 0xe6, 0x24, 0x75, 0x2f, 0xf3, 0xa3, 0xa6, 0x0d,
		0x11, 0x93, 0xa7, 0x85, 0xe1, 0x61, 0x13, 0x22, 0x66, 0x7d, 0xde, 0xf2,
		0x6d, 0x80, 0x98, 0xb2, 0x5d, 0x8f, 0x97, 0x4f, 0x43, 0xc4, 0x74, 0x55,
		0x98, 0xb7, 0x76, 0x99, 0xba, 0x42, 0x8c, 0x98, 0x7b, 0xc6, 0x44, 0xba,
		0x80, 0x53, 0xa0, 0x98, 0x36, 0x2d, 0xe2, 0x2c, 0xc8, 0xdb, 0x74, 0x15,
		0x27, 0xe6, 0xec, 0x77, 0x17, 0xcd, 0x58, 0x31, 0x79, 0xa1, 0x77, 0x51,
		0x45, 0x89, 0x79, 0x9e, 0x17, 0xe3, 0xbf, 0xd4, 0x8c, 0x15, 0xf3, 0xa4,
		0x5f, 0xe6, 0xfd, 0x5c, 0x33, 0xee, 0x1a, 0xf8, 0x22, 0xc8, 0x10, 0x37,
		0x4c, 0x07, 0xdd, 0x22, 0x46, 0xcc, 0xdd, 0xdc, 0x74, 0x1d, 0x23, 0xa6,
		0xbc, 0x9b, 0x28, 0xab, 0x18, 0xb3, 0xf6, 0xf1, 0xf0, 0xa7, 0x59, 0x04,
		0xd9, 0x85, 0x38, 0xed, 0x63, 0xae, 0x82, 0xec, 0xcf, 0x94, 0xfd, 0x3e,
		0xc4, 0x6d, 0x90, 0x98, 0xa2, 0x7c, 0x97, 0xb6, 0x97, 0x35, 0xa3, 0x6e,
		0xa3, 0xf5, 0xdb, 0x22, 0x55, 0x94, 0x98, 0xe2, 0xcd, 0xf6, 0x0f, 0x62,
		0xe3, 0xc6, 0x4c, 0xb7, 0x6f, 0xa7, 0x71, 0x63, 0x8e, 0x22, 0xc5, 0x94,
		0xdb, 0xa7, 0x1f, 0x79, 0x1f, 0x58, 0x8c, 0x98, 0xfb, 0x5f, 0xc0, 0x01,
		0xee, 0xa6, 0x49, 0x15, 0xe8, 0xd6, 0x9e, 0x7e, 0xda, 0x3c, 0xf4, 0x02,
		0x3c, 0x81, 0xa7, 0xdd, 0x7c, 0xbd, 0xdc, 0x0b, 0xf0, 0x6e, 0x9a, 0xa6,
		0xeb, 0x5c, 0x51, 0x5e, 0x86, 0x78, 0x6b, 0xe7, 0xff, 0xcf, 0xb2, 0xae,
		0x4f, 0x63, 0xac, 0x67, 0x72, 0x4c, 0xba, 0xf9, 0x1c, 0x64, 0x87, 0x7c,
		0xba, 0xde, 0xad, 0xdf, 0x3e, 0xfb, 0xc8, 0x31, 0x21, 0xa6, 0x83, 0x4d,
		0xcc, 0x6d, 0x84, 0xb9, 0x69, 0xf3, 0x73, 0xd3, 0x79, 0x88, 0x21, 0x6e,
		0x76, 0x39, 0x0c, 0x94, 0x55, 0x8c, 0x89, 0x72, 0x96, 0xef, 0xeb, 0xe5,
		0x3c, 0xc8, 0xe0, 0x5f, 0x4c, 0xea, 0x7a, 0x5e, 0x44, 0x89, 0xd9, 0xbb,
		0xa0, 0x10, 0x33, 0x46, 0xcc, 0xaa, 0x69, 0xaa, 0x5d, 0x47, 0x1c, 0x1f,
		0xf2, 0xa3, 0x41, 0xdf, 0x76, 0x8a, 0x11, 0xf3, 0x30, 0x42, 0x7d, 0xea,
		0x0f, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xfc,
		0xa3, 0x7e, 0x00, 0x58, 0xd7, 0xe2, 0x1f, 0x76, 0xeb, 0xcf, 0x4a, 0x00,
		0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52, 0x61, 0x77, 0x20, 0x70,
		0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74, 0x79, 0x70, 0x65, 0x20,
		0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c, 0xe3, 0xf2, 0x0c, 0x08,
		0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc, 0x49, 0xe5, 0x52, 0x00,
		0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23, 0x13, 0x4b, 0x93, 0x14,
		0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64, 0x03, 0x23, 0xb3, 0x54,
		0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4, 0x1c, 0xc4, 0x07, 0xcb,
		0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17, 0x11, 0x74, 0xf2, 0x42,
		0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae, 0x42,
		0x60, 0x82,
	})
}

func mstile70x70Png(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/png")
	setExpiresHeader(w)

	w.Write([]byte{
		0x89, 0x50, 0x4e, 0x47, 0x0d, 0x0a, 0x1a, 0x0a, 0x00, 0x00, 0x00, 0x0d,
		0x49, 0x48, 0x44, 0x52, 0x00, 0x00, 0x00, 0x80, 0x00, 0x00, 0x00, 0x80,
		0x04, 0x03, 0x00, 0x00, 0x00, 0x31, 0x10, 0x7c, 0xf8, 0x00, 0x00, 0x00,
		0x04, 0x67, 0x41, 0x4d, 0x41, 0x00, 0x00, 0xb1, 0x8f, 0x0b, 0xfc, 0x61,
		0x05, 0x00, 0x00, 0x00, 0x01, 0x73, 0x52, 0x47, 0x42, 0x00, 0xae, 0xce,
		0x1c, 0xe9, 0x00, 0x00, 0x00, 0x18, 0x50, 0x4c, 0x54, 0x45, 0x4c, 0x69,
		0x71, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0xdb, 0xeb,
		0xef, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0xdb, 0xeb, 0xef, 0xcc, 0xb7,
		0xb3, 0xed, 0x00, 0x00, 0x00, 0x08, 0x74, 0x52, 0x4e, 0x53, 0x00, 0xfe,
		0xda, 0x5f, 0x12, 0x20, 0x8d, 0x40, 0xb0, 0xec, 0x0a, 0x14, 0x00, 0x00,
		0x00, 0xf2, 0x49, 0x44, 0x41, 0x54, 0x68, 0xde, 0xed, 0xd6, 0x3d, 0x0f,
		0x82, 0x30, 0x10, 0x06, 0x60, 0x86, 0x12, 0xe6, 0x2b, 0x09, 0x3b, 0xf8,
		0xb5, 0x2a, 0x11, 0x67, 0xa2, 0x91, 0xb9, 0xf1, 0x63, 0xd7, 0x6a, 0xca,
		0xca, 0xa2, 0xfd, 0xfb, 0x96, 0xd5, 0x40, 0x82, 0x3d, 0xa3, 0x03, 0xef,
		0x33, 0xb0, 0x1c, 0xbc, 0x49, 0xd3, 0xbb, 0x96, 0x20, 0x00, 0x00, 0x00,
		0x00, 0x00, 0x80, 0xd1, 0x88, 0xac, 0xb5, 0xe5, 0x47, 0x85, 0x37, 0x07,
		0x22, 0x5a, 0x76, 0x15, 0xb6, 0x7d, 0x85, 0xef, 0x07, 0x18, 0xa3, 0xba,
		0x0a, 0x3b, 0xa3, 0x07, 0x06, 0xf4, 0xbe, 0xb5, 0x1d, 0x65, 0x40, 0xb8,
		0x31, 0xa6, 0x28, 0xfd, 0x03, 0x84, 0x76, 0x5b, 0x27, 0x2f, 0xfe, 0x01,
		0x15, 0x51, 0x96, 0xd2, 0xd4, 0x3f, 0x60, 0x25, 0xeb, 0xb3, 0xd5, 0xfe,
		0x01, 0x22, 0x8d, 0xdb, 0xa7, 0x62, 0x04, 0xcc, 0x78, 0xbb, 0xf0, 0x85,
		0x80, 0x44, 0xf1, 0xfa, 0x60, 0x45, 0x93, 0x07, 0x2b, 0xc0, 0x6d, 0xa3,
		0xbc, 0x35, 0x8c, 0x00, 0x91, 0xbb, 0x46, 0x9a, 0x2b, 0x46, 0x2b, 0x8b,
		0x67, 0x46, 0x74, 0x67, 0x0d, 0xd3, 0x3e, 0xa7, 0x98, 0x37, 0x8d, 0x61,
		0x2a, 0x99, 0xe3, 0x7c, 0x95, 0xe5, 0xdf, 0x02, 0xc2, 0xba, 0x6c, 0x97,
		0x90, 0x78, 0x2f, 0x21, 0xa2, 0xb9, 0xb5, 0x9a, 0x16, 0x8c, 0x80, 0x96,
		0x5c, 0xfa, 0xcf, 0x82, 0x4e, 0xdd, 0xf7, 0x35, 0xa7, 0x13, 0x8f, 0x1b,
		0x53, 0x7c, 0x3e, 0x0b, 0xeb, 0x73, 0x67, 0x41, 0x9c, 0x0e, 0x03, 0x03,
		0xb2, 0xac, 0xe9, 0x3c, 0xd4, 0xdd, 0xf1, 0xf8, 0x93, 0xcb, 0xb5, 0x32,
		0x3d, 0x97, 0x6b, 0x5b, 0x68, 0xf0, 0xff, 0x04, 0x00, 0x00, 0x00, 0x00,
		0x00, 0x83, 0xbd, 0x00, 0x34, 0x32, 0x3f, 0xc1, 0xa1, 0x7e, 0xcc, 0xc3,
		0x00, 0x00, 0x00, 0x57, 0x7a, 0x54, 0x58, 0x74, 0x52, 0x61, 0x77, 0x20,
		0x70, 0x72, 0x6f, 0x66, 0x69, 0x6c, 0x65, 0x20, 0x74, 0x79, 0x70, 0x65,
		0x20, 0x69, 0x70, 0x74, 0x63, 0x00, 0x00, 0x78, 0x9c, 0xe3, 0xf2, 0x0c,
		0x08, 0x71, 0x56, 0x28, 0x28, 0xca, 0x4f, 0xcb, 0xcc, 0x49, 0xe5, 0x52,
		0x00, 0x03, 0x23, 0x0b, 0x2e, 0x63, 0x0b, 0x13, 0x23, 0x13, 0x4b, 0x93,
		0x14, 0x03, 0x13, 0x20, 0x44, 0x80, 0x34, 0xc3, 0x64, 0x03, 0x23, 0xb3,
		0x54, 0x20, 0xcb, 0xd8, 0xd4, 0xc8, 0xc4, 0xcc, 0xc4, 0x1c, 0xc4, 0x07,
		0xcb, 0x80, 0x48, 0xa0, 0x4a, 0x2e, 0x00, 0xea, 0x17, 0x11, 0x74, 0xf2,
		0x42, 0x35, 0x95, 0x00, 0x00, 0x00, 0x00, 0x49, 0x45, 0x4e, 0x44, 0xae,
		0x42, 0x60, 0x82,
	})
}

func browserconfigXML(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "application/xml")
	setExpiresHeader(w)

	w.Write([]byte(`<?xml version="1.0" encoding="utf-8"?>
<browserconfig>
  <msapplication>
    <tile>
      <square70x70logo src="/mstile-70x70.png"/>
      <square150x150logo src="/mstile-150x150.png"/>
      <square310x310logo src="/mstile-310x310.png"/>
      <wide310x150logo src="/mstile-310x150.png"/>
      <TileColor>#272f32</TileColor>
    </tile>
  </msapplication>
</browserconfig>
`))
}

func manifestJSON(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "application/json")
	setExpiresHeader(w)

	w.Write([]byte(`{
	"name": "s",
	"icons": [
		{
			"src": "\/android-chrome-36x36.png",
			"sizes": "36x36",
			"type": "image\/png",
			"density": 0.75
		},
		{
			"src": "\/android-chrome-48x48.png",
			"sizes": "48x48",
			"type": "image\/png",
			"density": 1
		},
		{
			"src": "\/android-chrome-72x72.png",
			"sizes": "72x72",
			"type": "image\/png",
			"density": 1.5
		},
		{
			"src": "\/android-chrome-96x96.png",
			"sizes": "96x96",
			"type": "image\/png",
			"density": 2
		},
		{
			"src": "\/android-chrome-144x144.png",
			"sizes": "144x144",
			"type": "image\/png",
			"density": 3
		},
		{
			"src": "\/android-chrome-192x192.png",
			"sizes": "192x192",
			"type": "image\/png",
			"density": 4
		}
	],
	"display": "standalone"
}
`))
}

func safariPinnedTabSvg(w http.ResponseWriter, r *http.Request) {
	w.Header().Set("Content-Type", "image/svg+xml")
	setExpiresHeader(w)

	w.Write([]byte(`<?xml version="1.0" standalone="no"?>
<!DOCTYPE svg PUBLIC "-//W3C//DTD SVG 20010904//EN"
 "http://www.w3.org/TR/2001/REC-SVG-20010904/DTD/svg10.dtd">
<svg version="1.0" xmlns="http://www.w3.org/2000/svg"
 width="260.000000pt" height="260.000000pt" viewBox="0 0 260.000000 260.000000"
 preserveAspectRatio="xMidYMid meet">
<metadata>
Created by potrace 1.11, written by Peter Selinger 2001-2013
</metadata>
<g transform="translate(0.000000,260.000000) scale(0.100000,-0.100000)"
fill="#000000" stroke="none">
<path d="M0 1300 l0 -1300 1300 0 1300 0 0 1300 0 1300 -1300 0 -1300 0 0
-1300z m720 395 l0 -35 -55 0 -55 0 0 -365 0 -365 55 0 55 0 0 -35 0 -35 -100
0 -100 0 0 435 0 435 100 0 100 0 0 -35z m1370 -400 l0 -435 -100 0 -100 0 0
35 0 35 55 0 55 0 0 365 0 365 -55 0 -55 0 0 35 0 35 100 0 100 0 0 -435z
m-634 214 c43 -11 44 -13 44 -50 0 -44 2 -44 -64 -24 -90 27 -183 13 -200 -30
-21 -55 18 -98 102 -115 127 -26 182 -69 189 -147 9 -106 -70 -168 -212 -168
-44 1 -99 6 -122 13 -42 13 -43 14 -43 56 l0 44 53 -20 c100 -40 214 -24 232
32 18 57 -13 86 -125 115 -84 21 -129 50 -146 91 -32 76 -5 153 66 191 49 26
149 31 226 12z"/>
</g>
</svg>
`))
}
